@@ -32,6 +32,11 @@ if [ ${database_type} == 'mysql' ] && [ ! -f tests/${test_file}.mysql ]; then
 fi
 
 echo "###########################  start sshd ###########################"
+if [ ! -f /etc/ssh/ssh_host_rsa_key ]; then
+  ssh-keygen -t rsa -N '' -f /etc/ssh/ssh_host_rsa_key
+  ssh-keygen -t dsa -N '' -f /etc/ssh/ssh_host_dsa_key
+fi
+
 /usr/sbin/sshd -D  &
 
 if [ $database_type == 'mysql' ]; then
@@ -62,6 +67,7 @@ fi
 
 
 ulimit -c unlimited
+ulimit -S -n 524288
 
 #only privileged container can write core files
 if [ $test_file != 'connector_ssh/connector_ssh.robot' ] ; then
