@@ -269,11 +269,10 @@ void ba::visit(io::stream* visitor) {
       SPDLOG_LOGGER_TRACE(
           _logger,
           "BAM: ba current event needs update? downtime?: {}, state?: {} ; "
-          "dt:{}, state:{} from {}",
+          "dt:{}, state:{} ",
           _in_downtime != _event->obj().in_downtime(),
           com::centreon::broker::State(hard_state) != _event->obj().status(),
-          _in_downtime, static_cast<uint32_t>(hard_state),
-          _event->obj().start_time());
+          _in_downtime, static_cast<uint32_t>(hard_state));
       state_changed = true;
       _event->mut_obj().set_end_time(_last_kpi_update);
       visitor->write(std::static_pointer_cast<io::data>(_event));
@@ -411,11 +410,8 @@ void ba::set_inherited_downtime(const inherited_downtime& dwn) {
  */
 void ba::_open_new_event(io::stream* visitor,
                          com::centreon::broker::bam::state service_hard_state) {
-  SPDLOG_LOGGER_TRACE(
-      _logger,
-      "new pb_ba_event on ba {}  with status {}, downtime = {} from {}", _id,
-      com::centreon::broker::bam::state_str[service_hard_state], _in_downtime,
-      _last_kpi_update.get_time_t());
+  SPDLOG_LOGGER_TRACE(_logger, "new pb_ba_event on ba {} with downtime = {}",
+                      _id, _in_downtime);
   _event = std::make_shared<pb_ba_event>();
   BaEvent& data = _event->mut_obj();
   data.set_ba_id(_id);
@@ -562,6 +558,8 @@ std::shared_ptr<io::data> ba::_generate_virtual_service_status() const {
     o.set_perfdata(get_perfdata());
     o.set_service_id(_service_id);
     o.set_state_type(ServiceStatus_StateType_HARD);
+    _logger->trace("BAM: new virtual service status for BA {}: {}", _id,
+                   o.DebugString());
     return status;
   }
 }
@@ -673,3 +671,13 @@ void ba::dump(std::ofstream& output) const {
   }
   dump_parents(output);
 }
+
+/**
+ *
+ *  Get the hard impact introduced by acknowledged KPI.
+ *
+ *  @return Hard impact introduced by acknowledged KPI.
+ */
+int32_t ba::get_ack_impact_hard() const {
+  return _acknowledgement_count;
+}
