@@ -18,8 +18,6 @@
 
 #include "com/centreon/broker/bam/ba_best.hh"
 
-#include <fmt/format.h>
-
 #include <cassert>
 
 #include "bbdo/bam/ba_status.hh"
@@ -108,6 +106,9 @@ void ba_best::_apply_impact(kpi* kpi_ptr [[maybe_unused]],
     return order[new_state] < order[current_state];
   };
 
+  // Adjust values.
+  _acknowledgement_count += impact.hard_impact.get_acknowledgement();
+
   if (_dt_behaviour == configuration::ba::dt_ignore_kpi && impact.in_downtime)
     return;
 
@@ -159,6 +160,9 @@ void ba_best::_unapply_impact(kpi* kpi_ptr,
   // Prevent derive of values.
   _computed_soft_state = _computed_hard_state = state_critical;
 
+  // Adjust values.
+  _acknowledgement_count -= impact.hard_impact.get_acknowledgement();
+
   // We recompute all impacts, except the one to unapply...
   for (auto it = _impacts.begin(), end = _impacts.end(); it != end; ++it)
     if (it->first != kpi_ptr)
@@ -213,6 +217,7 @@ std::shared_ptr<pb_ba_status> ba_best::_generate_ba_status(
     status.set_last_state_change(_event->obj().start_time());
   else
     status.set_last_state_change(get_last_kpi_update());
+  status.set_level_acknowledgement(_acknowledgement_count);
   status.set_state(com::centreon::broker::State(get_state_hard()));
   status.set_state_changed(state_changed);
   std::string perfdata = get_perfdata();
