@@ -23,7 +23,6 @@
 #include "bbdo/bam/ba_status.hh"
 #include "bbdo/bam/kpi_status.hh"
 #include "bbdo/bam/rebuild.hh"
-#include "com/centreon/broker/bam/configuration/reader_exception.hh"
 #include "com/centreon/broker/bam/configuration/reader_v2.hh"
 #include "com/centreon/broker/bam/event_cache_visitor.hh"
 #include "com/centreon/broker/config/applier/state.hh"
@@ -61,7 +60,7 @@ monitoring_stream::monitoring_stream(
       _ext_cmd_file(ext_cmd_file),
       _logger{logger},
       _applier(_logger),
-      _mysql(db_cfg.auto_commit_conf()),
+      _mysql(db_cfg.auto_commit_conf(), logger),
       _conf_queries_per_transaction(db_cfg.get_queries_per_transaction()),
       _pending_events(0),
       _pending_request(0),
@@ -170,6 +169,26 @@ bool monitoring_stream::read(std::shared_ptr<io::data>& d, time_t deadline) {
   return true;
 }
 
+/**
+ *  Rebuild index and metrics cache.
+ */
+void monitoring_stream::update() {
+  SPDLOG_LOGGER_TRACE(_logger, "BAM: monitoring_stream update");
+  try {
+    configuration::state s{_logger};
+    configuration::reader_v2 r(_mysql, _storage_db_cfg);
+    r.read(s);
+    _applier.apply(s);
+    _ba_mapping = s.get_ba_svc_mapping();
+    _rebuild();
+    initialize();
+    // Read cache.
+    _read_cache();
+  } catch (std::exception const& e) {
+    throw msg_fmt("BAM: could not process configuration update: {}", e.what());
+  }
+}
+
 // When bulk statements are available.
 struct bulk_ba_binder {
   const std::shared_ptr<io::data>& event;
@@ -326,44 +345,6 @@ struct kpi_binder {
   }
 };
 
-/**
- *  Rebuild index and metrics cache.
- */
-void monitoring_stream::update() {
-  SPDLOG_LOGGER_TRACE(_logger, "BAM: monitoring_stream update");
-  try {
-    configuration::state s{_logger};
-    configuration::reader_v2 r(_mysql, _storage_db_cfg);
-    r.read(s);
-    _applier.apply(s);
-    _ba_mapping = s.get_ba_svc_mapping();
-    _rebuild();
-    initialize();
-    // Read cache.
-    _read_cache();
-  } catch (const configuration::reader_exception& e) {
-    SPDLOG_LOGGER_ERROR(_logger, e.what());
-    if (e.ba_id()) {  // we create a fake pb_ba_status to fill comment field of
-                      // mod_bam table
-      auto fake_event = std::make_shared<pb_ba_status>();
-      BaStatus& fake_event_data = fake_event->mut_obj();
-      fake_event_data.set_ba_id(e.ba_id());
-      fake_event_data.set_state(com::centreon::broker::State::UNKNOWN);
-      fake_event_data.set_output(e.what());
-      if (_ba_query->is_bulk())
-        _ba_query->add_bulk_row(bulk_ba_binder{fake_event});
-      else
-        _ba_query->add_multi_row(ba_binder{fake_event});
-      flush();
-    }
-    throw;
-  } catch (const std::exception& e) {
-    SPDLOG_LOGGER_ERROR(
-        _logger, "BAM: could not process configuration update: {}", e.what());
-    throw;
-  }
-}
-
 /**
  *  Write an event.
  *
@@ -590,10 +571,9 @@ int monitoring_stream::write(const std::shared_ptr<io::data>& data) {
       timestamp now = timestamp::now();
       pb_inherited_downtime const& dwn =
           *std::static_pointer_cast<pb_inherited_downtime const>(data);
-      SPDLOG_LOGGER_TRACE(_logger,
-                          "BAM: processing pb inherited downtime (ba id {}, "
-                          "now {}, in downtime {})",
-                          dwn.obj().ba_id(), now, dwn.obj().in_downtime());
+      SPDLOG_LOGGER_TRACE(
+          _logger, "BAM: processing pb inherited downtime (ba id {}, now {}",
+          dwn.obj().ba_id(), now);
       if (dwn.obj().in_downtime())
         cmd = fmt::format(
             "[{}] "
@@ -660,13 +640,13 @@ void monitoring_stream::_prepare() {
         "UPDATE mod_bam SET "
         "current_level=?,acknowledged=?,downtime=?,last_state_change=?,"
         "in_downtime=?,current_status=?,comment=? WHERE ba_id=?",
-        _conf_queries_per_transaction);
+        _conf_queries_per_transaction, _logger);
     _kpi_query = std::make_unique<database::bulk_or_multi>(
         _mysql,
         "UPDATE mod_bam_kpi SET acknowledged=?,current_status=?,downtime=?, "
         "last_level=?,state_type=?,last_state_change=?,last_impact=?, "
         "valid=?,in_downtime=? WHERE kpi_id=?",
-        _conf_queries_per_transaction);
+        _conf_queries_per_transaction, _logger);
 
   } else {
     _ba_query = std::make_unique<database::bulk_or_multi>(
