@@ -158,7 +158,7 @@ TEST_F(BamExpBuilder, Valid8) {
 
 TEST_F(BamExpBuilder, UnknownService1) {
   config::applier::modules modules(_logger);
-  modules.load_file("./broker/neb/10-neb.so");
+  modules.load_file("./broker/lib/10-neb.so");
   bam::exp_parser p("{host_1 service_1} {IS} {OK}");
   bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
@@ -170,7 +170,7 @@ TEST_F(BamExpBuilder, UnknownService1) {
 
 TEST_F(BamExpBuilder, UnknownService2) {
   config::applier::modules modules(_logger);
-  modules.load_file("./broker/neb/10-neb.so");
+  modules.load_file("./broker/lib/10-neb.so");
   bam::exp_parser p("{host_1 service_1} {IS} {CRITICAL}");
   bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
@@ -182,7 +182,7 @@ TEST_F(BamExpBuilder, UnknownService2) {
 
 TEST_F(BamExpBuilder, OkService2) {
   config::applier::modules modules(_logger);
-  modules.load_file("./broker/neb/10-neb.so");
+  modules.load_file("./broker/lib/10-neb.so");
   bam::exp_parser p("{host_1 service_1} {IS} {CRITICAL}");
   bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
@@ -207,7 +207,7 @@ TEST_F(BamExpBuilder, OkService2) {
 
 TEST_F(BamExpBuilder, CritService2) {
   config::applier::modules modules(_logger);
-  modules.load_file("./broker/neb/10-neb.so");
+  modules.load_file("./broker/lib/10-neb.so");
   bam::exp_parser p("{host_1 service_1} {IS} {CRITICAL}");
   bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
@@ -232,7 +232,7 @@ TEST_F(BamExpBuilder, CritService2) {
 
 TEST_F(BamExpBuilder, CritOkService1) {
   config::applier::modules modules(_logger);
-  modules.load_file("./broker/neb/10-neb.so");
+  modules.load_file("./broker/lib/10-neb.so");
   bam::exp_parser p(
       "{host_1 service_1} {IS} {CRITICAL} {OR} {host_1 service_2} {IS} {OK}");
   bam::hst_svc_mapping mapping(_logger);
@@ -273,7 +273,7 @@ TEST_F(BamExpBuilder, CritOkService1) {
 
 TEST_F(BamExpBuilder, CritOkService2) {
   config::applier::modules modules(_logger);
-  modules.load_file("./broker/neb/10-neb.so");
+  modules.load_file("./broker/lib/10-neb.so");
   bam::exp_parser p(
       "{host_1 service_1} {IS} {CRITICAL} {OR} {host_1 service_2} {IS} {OK}");
   bam::hst_svc_mapping mapping(_logger);
@@ -321,7 +321,7 @@ TEST_F(BamExpBuilder, CritOkService2) {
 
 TEST_F(BamExpBuilder, CritOkService3) {
   config::applier::modules modules(_logger);
-  modules.load_file("./broker/neb/10-neb.so");
+  modules.load_file("./broker/lib/10-neb.so");
   bam::exp_parser p(
       "{host_1 service_1} {IS} {CRITICAL} {OR} {host_1 service_2} {IS} {OK}");
   bam::hst_svc_mapping mapping(_logger);
@@ -369,7 +369,7 @@ TEST_F(BamExpBuilder, CritOkService3) {
 
 TEST_F(BamExpBuilder, CritAndOkService1) {
   config::applier::modules modules(_logger);
-  modules.load_file("./broker/neb/10-neb.so");
+  modules.load_file("./broker/lib/10-neb.so");
   bam::exp_parser p(
       "{host_1 service_1} {IS} {CRITICAL} {AND} {host_1 service_2} {IS} {OK}");
   bam::hst_svc_mapping mapping(_logger);
@@ -418,7 +418,7 @@ TEST_F(BamExpBuilder, CritAndOkService1) {
 
 TEST_F(BamExpBuilder, CritAndOkService2) {
   config::applier::modules modules(_logger);
-  modules.load_file("./broker/neb/10-neb.so");
+  modules.load_file("./broker/lib/10-neb.so");
   bam::exp_parser p(
       "{host_1 service_1} {IS} {CRITICAL} {AND} {host_1 service_2} {IS} {OK}");
   bam::hst_svc_mapping mapping(_logger);
@@ -466,7 +466,7 @@ TEST_F(BamExpBuilder, CritAndOkService2) {
 
 TEST_F(BamExpBuilder, CritAndOkService3) {
   config::applier::modules modules(_logger);
-  modules.load_file("./broker/neb/10-neb.so");
+  modules.load_file("./broker/lib/10-neb.so");
   bam::exp_parser p(
       "{host_1 service_1} {IS} {CRITICAL} {AND} {host_1 service_2} {IS} {OK}");
   bam::hst_svc_mapping mapping(_logger);
@@ -514,7 +514,7 @@ TEST_F(BamExpBuilder, CritAndOkService3) {
 
 TEST_F(BamExpBuilder, NotCritService3) {
   config::applier::modules modules(_logger);
-  modules.load_file("./broker/neb/10-neb.so");
+  modules.load_file("./broker/lib/10-neb.so");
   bam::exp_parser p("({host_1 service_1} {NOT} {CRITICAL})");
   bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
@@ -550,7 +550,7 @@ TEST_F(BamExpBuilder, NotCritService3) {
 
 TEST_F(BamExpBuilder, ExpressionWithService) {
   config::applier::modules modules(_logger);
-  modules.load_file("./broker/neb/10-neb.so");
+  modules.load_file("./broker/lib/10-neb.so");
   bam::exp_parser p("({host_1 service_1} {NOT} {CRITICAL})");
   bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
@@ -589,7 +589,7 @@ TEST_F(BamExpBuilder, ExpressionWithService) {
 
 TEST_F(BamExpBuilder, ReverseExpressionWithService) {
   config::applier::modules modules(_logger);
-  modules.load_file("./broker/neb/10-neb.so");
+  modules.load_file("./broker/lib/10-neb.so");
   bam::exp_parser p("({host_1 service_1} {NOT} {CRITICAL})");
   bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
@@ -628,7 +628,7 @@ TEST_F(BamExpBuilder, ReverseExpressionWithService) {
 
 TEST_F(BamExpBuilder, KpiBoolexpWithService) {
   config::applier::modules modules(_logger);
-  modules.load_file("./broker/neb/10-neb.so");
+  modules.load_file("./broker/lib/10-neb.so");
   bam::exp_parser p("({host_1 service_1} {NOT} {CRITICAL})");
   bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
@@ -673,7 +673,7 @@ TEST_F(BamExpBuilder, KpiBoolexpWithService) {
 
 TEST_F(BamExpBuilder, KpiBoolexpReversedImpactWithService) {
   config::applier::modules modules(_logger);
-  modules.load_file("./broker/neb/10-neb.so");
+  modules.load_file("./broker/lib/10-neb.so");
   bam::exp_parser p("({host_1 service_1} {NOT} {CRITICAL})");
   bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
@@ -716,7 +716,7 @@ TEST_F(BamExpBuilder, KpiBoolexpReversedImpactWithService) {
 
 TEST_F(BamExpBuilder, BoolexpServiceXorService) {
   config::applier::modules modules(_logger);
-  modules.load_file("./broker/neb/10-neb.so");
+  modules.load_file("./broker/lib/10-neb.so");
   bam::exp_parser p(
       "({host_1 service_1} {IS} {CRITICAL}) {XOR} ({host_1 service_2} {IS} "
       "{CRITICAL})");
@@ -772,7 +772,7 @@ TEST_F(BamExpBuilder, BoolexpServiceXorService) {
 
 TEST_F(BamExpBuilder, BoolexpLTWithServiceStatus) {
   config::applier::modules modules(_logger);
-  modules.load_file("./broker/neb/10-neb.so");
+  modules.load_file("./broker/lib/10-neb.so");
   bam::exp_parser p("{host_1 service_1} < {host_1 service_2}");
   bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
@@ -826,7 +826,7 @@ TEST_F(BamExpBuilder, BoolexpLTWithServiceStatus) {
 
 TEST_F(BamExpBuilder, BoolexpKpiService) {
   config::applier::modules modules(_logger);
-  modules.load_file("./broker/neb/10-neb.so");
+  modules.load_file("./broker/lib/10-neb.so");
   bam::exp_parser p(
       "{host_1 service_1} {IS} {CRITICAL} {OR} {host_1 service_2} {IS} "
       "{CRITICAL}");
@@ -891,7 +891,7 @@ TEST_F(BamExpBuilder, BoolexpKpiService) {
  * expression. */
 TEST_F(BamExpBuilder, BoolexpKpiServiceAndBoolExpression) {
   config::applier::modules modules(_logger);
-  modules.load_file("./broker/neb/10-neb.so");
+  modules.load_file("./broker/lib/10-neb.so");
   bam::exp_parser p(
       "{host_1 service_1} {IS} {CRITICAL} {OR} {host_1 service_2} {IS} "
       "{CRITICAL}");
@@ -998,7 +998,7 @@ TEST_F(BamExpBuilder, BoolexpKpiServiceAndBoolExpression) {
  * with impact_if set to false. */
 TEST_F(BamExpBuilder, BoolexpKpiServiceAndBoolExpressionAndOperator) {
   config::applier::modules modules(_logger);
-  modules.load_file("./broker/neb/10-neb.so");
+  modules.load_file("./broker/lib/10-neb.so");
   bam::exp_parser p(
       "{host_1 service_1} {IS} {CRITICAL} {AND} {host_1 service_2} {IS} "
       "{CRITICAL}");
