@@ -1,22 +1,23 @@
 /**
- * Copyright 2017 Centreon
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- *
- * For more information : contact@centreon.com
- */
+* Copyright 2017 Centreon
+*
+* Licensed under the Apache License, Version 2.0 (the "License");
+* you may not use this file except in compliance with the License.
+* You may obtain a copy of the License at
+*
+*     http://www.apache.org/licenses/LICENSE-2.0
+*
+* Unless required by applicable law or agreed to in writing, software
+* distributed under the License is distributed on an "AS IS" BASIS,
+* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+* See the License for the specific language governing permissions and
+* limitations under the License.
+*
+* For more information : contact@centreon.com
+*/
 
 #include "com/centreon/broker/generator/factory.hh"
+#include <memory>
 #include "com/centreon/broker/generator/endpoint.hh"
 
 using namespace com::centreon::broker;
@@ -35,9 +36,9 @@ using namespace com::centreon::broker::generator;
  *
  *  @return True if configuration matches any of the generator streams.
  */
-bool factory::has_endpoint(const config::endpoint& cfg,
-                           io::extension* ext [[maybe_unused]]) const {
-  return cfg.type == "generator_receiver" || cfg.type == "generator_sender";
+bool factory::has_endpoint(config::endpoint& cfg) {
+  return ((cfg.type == "generator_receiver") ||
+          (cfg.type == "generator_sender"));
 }
 
 /**
