@@ -56,21 +56,15 @@ std::string factory::find_param(config::endpoint const& cfg,
  *
  *  @return True if the configuration matches the storage layer.
  */
-bool factory::has_endpoint(const config::endpoint& cfg,
-                           io::extension* ext) const {
+bool factory::has_endpoint(config::endpoint& cfg, io::extension* ext) {
+  bool is_ifdb{absl::EqualsIgnoreCase(cfg.type, _name)};
   if (ext)
     *ext = io::extension(boost::algorithm::to_upper_copy(_name), false, false);
-  return absl::EqualsIgnoreCase(cfg.type, _name);
-}
-
-/**
- * @brief Set the default values to the endpoint config read from cfg files
- *
- * @param cfg config to update
- */
-void factory::set_default_values(config::endpoint& cfg) const {
-  cfg.params["cache"] = "yes";
-  cfg.cache_enabled = true;
+  if (is_ifdb) {
+    cfg.params["cache"] = "yes";
+    cfg.cache_enabled = true;
+  }
+  return is_ifdb;
 }
 
 /**
@@ -219,18 +213,11 @@ void factory::create_conf(const config::endpoint& cfg,
   }
 
   asio::ip::tcp::resolver resolver{*_io_context};
-  asio::ip::tcp::resolver::query query{addr, std::to_string(port)};
-
-  asio::ip::tcp::resolver::iterator res_it;
-  try {
-    res_it = resolver.resolve(query);
-    asio::ip::tcp::resolver::iterator res_end;
-    if (res_it == res_end) {
-      throw msg_fmt("can't resolve {}:{} for {}", addr, port, cfg.name);
-    }
-  } catch (const boost::exception& e) {
+  boost::system::error_code err;
+  auto endpoints = resolver.resolve(addr, std::to_string(port), err);
+  if (err || endpoints.empty()) {
     throw msg_fmt("can't resolve {}:{} for {} : {}", addr, port, cfg.name,
-                  boost::diagnostic_information(e));
+                  err.message());
   }
 
   asio::ssl::context_base::method ssl_method =
@@ -252,7 +239,7 @@ void factory::create_conf(const config::endpoint& cfg,
   }
 
   common::http::http_config http_cfg(
-      res_it->endpoint(), addr, encryption, connect_timeout, send_timeout,
+      endpoints, addr, encryption, connect_timeout, send_timeout,
       receive_timeout, second_tcp_keep_alive_interval, std::chrono::seconds(1),
       0, default_http_keepalive_duration, max_connections, ssl_method,
       certificate_path);
