@@ -53,21 +53,15 @@ static std::string find_param(config::endpoint const& cfg,
  *
  *  @return True if the configuration matches the storage layer.
  */
-bool factory::has_endpoint(const config::endpoint& cfg,
-                           io::extension* ext) const {
+bool factory::has_endpoint(config::endpoint& cfg, io::extension* ext) {
+  bool is_ifdb{absl::EqualsIgnoreCase(cfg.type, "influxdb")};
   if (ext)
     *ext = io::extension("INFLUXDB", false, false);
-  return absl::EqualsIgnoreCase(cfg.type, "influxdb");
-}
-
-/**
- * @brief Set the default values to the endpoint config read from cfg files
- *
- * @param cfg config to update
- */
-void factory::set_default_values(config::endpoint& cfg) const {
-  cfg.params["cache"] = "yes";
-  cfg.cache_enabled = true;
+  if (is_ifdb) {
+    cfg.params["cache"] = "yes";
+    cfg.cache_enabled = true;
+  }
+  return is_ifdb;
 }
 
 /**
