@@ -19,10 +19,12 @@
 #include "com/centreon/broker/lua/broker_utils.hh"
 
 #include <fmt/format.h>
+#include <lua.h>
 #include <sys/stat.h>
 #include "absl/strings/str_split.h"
 #include "absl/strings/string_view.h"
 #include "com/centreon/broker/config/applier/state.hh"
+#include "common/crypto/base64.hh"
 
 #include <openssl/evp.h>
 #include <cstdlib>
@@ -47,6 +49,7 @@
 using namespace com::centreon::broker;
 using namespace com::centreon::broker::lua;
 using namespace com::centreon::exceptions;
+using namespace com::centreon::common::crypto;
 using namespace nlohmann;
 using com::centreon::common::log_v2::log_v2;
 
@@ -775,6 +778,42 @@ static int l_broker_url_encode(lua_State* L) {
   return 1;
 }
 
+/**
+ *  The Lua base64_encode function
+ *
+ * @param L The Lua interpreter
+ *
+ * @return 1
+ */
+static int l_broker_base64_encode(lua_State* L) {
+  size_t len;
+  char const* str = lua_tolstring(L, -1, &len);
+  std::string_view sv(str, len);
+
+  std::string retval = base64_encode(sv);
+
+  lua_pushlstring(L, retval.c_str(), retval.size());
+  return 1;
+}
+
+/**
+ *  The Lua base64_decode function
+ *
+ * @param L The Lua interpreter
+ *
+ * @return 1
+ */
+static int l_broker_base64_decode(lua_State* L) {
+  size_t len;
+  char const* str = lua_tolstring(L, -1, &len);
+  std::string_view sv(str, len);
+
+  std::string retval = base64_decode(sv);
+
+  lua_pushlstring(L, retval.c_str(), retval.size());
+  return 1;
+}
+
 /**
  * @brief The Lua stat function that is just a binding to the C stat().
  * The Lua function will return the asked object or nil followed by an
@@ -815,25 +854,22 @@ static void md5_message(const unsigned char* message,
                         unsigned char** digest,
                         unsigned int* digest_len) {
   EVP_MD_CTX* mdctx;
-  auto handle_error = [](const std::string& msg) {
-    auto logger = log_v2::instance().get(log_v2::LUA);
-    logger->error(msg);
-  };
+  auto logger = log_v2::instance().get(log_v2::LUA);
   if ((mdctx = EVP_MD_CTX_new()) == nullptr) {
-    handle_error("lua: fail to call MD5 (EVP_MD_CTX_new call)");
+    logger->error("lua: fail to call MD5 (EVP_MD_CTX_new call)");
   }
   if (1 != EVP_DigestInit_ex(mdctx, EVP_md5(), nullptr)) {
-    handle_error("lua: fail to call MD5 (EVP_DigestInit_ex call)");
+    logger->error("lua: fail to call MD5 (EVP_DigestInit_ex call)");
   }
   if (1 != EVP_DigestUpdate(mdctx, message, message_len)) {
-    handle_error("lua: fail to call MD5 (EVP_DigestUpdate call)");
+    logger->error("lua: fail to call MD5 (EVP_DigestUpdate call)");
   }
   if ((*digest = (unsigned char*)OPENSSL_malloc(EVP_MD_size(EVP_md5()))) ==
       nullptr) {
-    handle_error("lua: fail to call MD5 (OPENSSL_malloc call)");
+    logger->error("lua: fail to call MD5 (OPENSSL_malloc call)");
   }
   if (1 != EVP_DigestFinal_ex(mdctx, *digest, digest_len)) {
-    handle_error("lua: fail to call MD5 (EVP_DigestFinal_ex call)");
+    logger->error("lua: fail to call MD5 (EVP_DigestFinal_ex call)");
   }
   EVP_MD_CTX_free(mdctx);
 }
@@ -892,6 +928,8 @@ void broker_utils::broker_utils_reg(lua_State* L) {
                               {"json_decode", l_broker_json_decode},
                               {"parse_perfdata", l_broker_parse_perfdata},
                               {"url_encode", l_broker_url_encode},
+                              {"base64_encode", l_broker_base64_encode},
+                              {"base64_decode", l_broker_base64_decode},
                               {"stat", l_broker_stat},
                               {"md5", l_broker_md5},
                               {"bbdo_version", l_broker_bbdo_version},
