@@ -17,9 +17,9 @@
  */
 #include "com/centreon/broker/tcp/tcp_async.hh"
 
+#include "com/centreon/common/pool.hh"
 #include "com/centreon/exceptions/msg_fmt.hh"
 #include "common/log_v2/log_v2.hh"
-#include "com/centreon/common/pool.hh"
 
 using namespace com::centreon::exceptions;
 using namespace com::centreon::broker;
@@ -100,7 +100,8 @@ void tcp_async::unload() {
  */
 tcp_async::tcp_async()
     : _clear_available_con_running(false),
-      _logger{log_v2::instance().get(log_v2::TCP)} {}
+      _logger{log_v2::instance().get(log_v2::TCP)},
+      _io_context(com::centreon::common::pool::io_context_ptr()) {}
 
 /**
  * @brief Stop the timer that clears available connections.
@@ -169,31 +170,29 @@ std::shared_ptr<asio::ip::tcp::acceptor> tcp_async::create_acceptor(
     listen_endpoint =
         asio::ip::tcp::endpoint(asio::ip::tcp::v4(), conf->get_port());
   else {
-    asio::ip::tcp::resolver::query query(conf->get_host(),
-                                         std::to_string(conf->get_port()));
-    asio::ip::tcp::resolver resolver(com::centreon::common::pool::io_context());
+    asio::ip::tcp::resolver resolver(*_io_context);
     boost::system::error_code ec;
-    asio::ip::tcp::resolver::iterator it = resolver.resolve(query, ec), end;
-    if (ec) {
+    auto endpoints = resolver.resolve(conf->get_host(),
+                                      std::to_string(conf->get_port()), ec);
+    if (ec || endpoints.empty()) {
       _logger->error("TCP: error while resolving '{}' name: {}",
                      conf->get_host(), ec.message());
       listen_endpoint =
           asio::ip::tcp::endpoint(asio::ip::tcp::v4(), conf->get_port());
     } else {
-      for (; it != end; ++it) {
-        listen_endpoint = *it;
+      for (auto ep : endpoints) {
+        listen_endpoint = ep;
         _logger->info("TCP: {} gives address {}", conf->get_host(),
                       listen_endpoint.address().to_string());
-        if (listen_endpoint.address().is_v4())
+        if (ep.endpoint().address().is_v4())
           break;
       }
     }
   }
   auto retval{std::make_shared<asio::ip::tcp::acceptor>(
-      com::centreon::common::pool::io_context(), listen_endpoint)};
+      *_io_context, listen_endpoint)};  // the constructor has the
+                                        // reuse_address option true by default
 
-  asio::ip::tcp::acceptor::reuse_address option(true);
-  retval->set_option(option);
   return retval;
 }
 
@@ -217,10 +216,8 @@ void tcp_async::_clear_available_con(boost::system::error_code ec) {
       for (auto it = _acceptor_available_con.begin();
            it != _acceptor_available_con.end();) {
         if (now >= it->second.second + 10) {
-          log_v2::instance()
-              .get(log_v2::TCP)
-              ->debug("Destroying connection to '{}'",
-                      it->second.first->peer());
+          _logger->debug("Destroying connection to '{}'",
+                         it->second.first->peer());
           it = _acceptor_available_con.erase(it);
         } else
           ++it;
@@ -251,8 +248,7 @@ void tcp_async::start_acceptor(
   _logger->trace("Start acceptor");
   std::lock_guard<std::mutex> l(_acceptor_available_con_m);
   if (!_timer)
-    _timer = std::make_unique<asio::steady_timer>(
-        com::centreon::common::pool::instance().io_context());
+    _timer = std::make_unique<asio::steady_timer>(*_io_context);
 
   if (!_clear_available_con_running)
     _clear_available_con_running = true;
@@ -264,8 +260,8 @@ void tcp_async::start_acceptor(
         me->_clear_available_con(err);
       });
 
-  tcp_connection::pointer new_connection = std::make_shared<tcp_connection>(
-      com::centreon::common::pool::io_context(), _logger);
+  tcp_connection::pointer new_connection =
+      std::make_shared<tcp_connection>(*_io_context, _logger);
 
   _logger->debug("Waiting for a connection");
   acceptor->async_accept(new_connection->socket(),
@@ -282,16 +278,15 @@ void tcp_async::start_acceptor(
  */
 void tcp_async::stop_acceptor(
     std::shared_ptr<asio::ip::tcp::acceptor> acceptor) {
-  auto logger = log_v2::instance().get(log_v2::TCP);
-  logger->debug("stop acceptor");
+  _logger->debug("stop acceptor");
   std::lock_guard<std::mutex> l(_acceptor_available_con_m);
   boost::system::error_code ec;
   acceptor->cancel(ec);
   if (ec)
-    logger->warn("Error while cancelling acceptor: {}", ec.message());
+    _logger->warn("Error while cancelling acceptor: {}", ec.message());
   acceptor->close(ec);
   if (ec)
-    logger->warn("Error while closing acceptor: {}", ec.message());
+    _logger->warn("Error while closing acceptor: {}", ec.message());
 }
 
 /**
@@ -306,12 +301,11 @@ void tcp_async::handle_accept(std::shared_ptr<asio::ip::tcp::acceptor> acceptor,
                               const boost::system::error_code& ec,
                               const tcp_config::pointer& conf) {
   /* If we got a connection, we store it */
-  auto logger = log_v2::instance().get(log_v2::TCP);
   if (!ec) {
     boost::system::error_code ecc;
     new_connection->update_peer(ecc);
     if (ecc)
-      logger->error(
+      _logger->error(
           "tcp acceptor handling connection: unable to get peer endpoint: {}",
           ecc.message());
     else {
@@ -327,7 +321,7 @@ void tcp_async::handle_accept(std::shared_ptr<asio::ip::tcp::acceptor> acceptor,
       start_acceptor(acceptor, conf);
     }
   } else
-    logger->info("TCP acceptor interrupted: {}", ec.message());
+    _logger->info("TCP acceptor interrupted: {}", ec.message());
 }
 
 /**
@@ -340,42 +334,38 @@ void tcp_async::handle_accept(std::shared_ptr<asio::ip::tcp::acceptor> acceptor,
  */
 tcp_connection::pointer tcp_async::create_connection(
     const tcp_config::pointer& conf) {
-  auto logger = log_v2::instance().get(log_v2::TCP);
-  logger->trace("create connection to host {}:{}", conf->get_host(),
-                conf->get_port());
+  _logger->trace("create connection to host {}:{}", conf->get_host(),
+                 conf->get_port());
   tcp_connection::pointer conn = std::make_shared<tcp_connection>(
-      com::centreon::common::pool::io_context(), _logger, conf->get_host(), conf->get_port());
+      *_io_context, _logger, conf->get_host(), conf->get_port());
   asio::ip::tcp::socket& sock = conn->socket();
 
-  asio::ip::tcp::resolver resolver(com::centreon::common::pool::io_context());
-  asio::ip::tcp::resolver::query query(conf->get_host(),
-                                       std::to_string(conf->get_port()));
-  asio::ip::tcp::resolver::iterator it = resolver.resolve(query), end;
+  boost::system::error_code err;
+  asio::ip::tcp::resolver resolver(*_io_context);
 
-  boost::system::error_code err{make_error_code(asio::error::host_unreachable)};
+  auto endpoints =
+      resolver.resolve(conf->get_host(), std::to_string(conf->get_port()), err);
 
-  // it can resolve multiple addresses like ipv4 or ipv6
-  // We need to try all to find the first available socket
-  for (; err && it != end; ++it) {
-    sock.connect(*it, err);
-
-    if (err)
-      sock.close();
-  }
-
-  /* Connection refused */
-  if (err.value() == 111) {
-    logger->error("TCP: Connection refused to {}:{}", conf->get_host(),
-                  conf->get_port());
-    throw std::system_error(err);
-  } else if (err) {
-    logger->error("TCP: could not connect to {}:{}", conf->get_host(),
-                  conf->get_port());
+  if (err) {
+    _logger->error("TCP: could not resolve {}:{}", conf->get_host(),
+                   conf->get_port());
     throw msg_fmt(err.message());
-  } else {
-    _set_sock_opt(sock, conf, _logger);
-    return conn;
   }
+
+  asio::connect(sock, endpoints, err);
+
+  if (err && err.value() == 111 /* Connection refused */) {
+    _logger->error("TCP: Connection refused to {}:{}", conf->get_host(),
+                   conf->get_port());
+    throw std::system_error(err);
+  }
+  if (err) {
+    _logger->error("TCP: could not connect to {}:{} : {}", conf->get_host(),
+                   conf->get_port(), err.message());
+    throw std::system_error(err);
+  }
+  _set_sock_opt(sock, conf, _logger);
+  return conn;
 }
 
 void tcp_async::_set_sock_opt(asio::ip::tcp::socket& sock,
@@ -388,28 +378,21 @@ void tcp_async::_set_sock_opt(asio::ip::tcp::socket& sock,
   tcp_user_timeout option5(1000 * (conf->get_second_keepalive_interval() *
                                    (conf->get_keepalive_count() + 1)));
   boost::system::error_code err;
-  sock.set_option(option1, err);
-  if (err) {
-    SPDLOG_LOGGER_ERROR(logger, "fail to set keepalive option {}",
-                        err.message());
-  } else {
-    sock.set_option(option2, err);
+
+  auto set = [&](auto opt, std::string_view desc) {
+    sock.set_option(opt, err);
     if (err) {
-      SPDLOG_LOGGER_ERROR(logger, "fail to set keepalive cnt {}",
-                          err.message());
-    }
-    sock.set_option(option3, err);
-    if (err) {
-      SPDLOG_LOGGER_ERROR(logger, "fail to set keepalive idle {}",
-                          err.message());
-    }
-    sock.set_option(option4, err);
-    if (err) {
-      SPDLOG_LOGGER_ERROR(logger, "fail to set keepalive interval {}",
+      SPDLOG_LOGGER_ERROR(logger, "fail to set {} option {}", desc,
                           err.message());
     }
+    return !err;
+  };
+
+  if (set(option1, "keepalive")) {
+    set(option2, "keepalive count");
+    set(option3, "keepalive idle");
+    set(option4, "keepalive interval");
   }
-  sock.set_option(option5, err);
-  if (err)
-    SPDLOG_LOGGER_ERROR(logger, "fail to set keepalive option");
+
+  set(option5, "user timeout");
 }
