@@ -1,4 +1,4 @@
-/*
+/**
  * Copyright 2021 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -19,16 +19,13 @@
 
 #include "com/centreon/broker/tcp/acceptor.hh"
 
-#include <fmt/format.h>
 #include <gtest/gtest.h>
 
-#include <nlohmann/json.hpp>
 
 #include "com/centreon/broker/io/raw.hh"
 #include "com/centreon/broker/misc/buffer.hh"
 #include "com/centreon/broker/misc/misc.hh"
 #include "com/centreon/broker/misc/string.hh"
-#include "com/centreon/broker/pool.hh"
 #include "com/centreon/broker/tcp/connector.hh"
 #include "com/centreon/broker/tcp/tcp_async.hh"
 #include "com/centreon/broker/tls/acceptor.hh"
@@ -40,8 +37,6 @@
 using namespace com::centreon::broker;
 using namespace com::centreon::exceptions;
 
-extern std::shared_ptr<asio::io_context> g_io_context;
-
 const static std::string test_addr("127.0.0.1");
 constexpr static uint16_t test_port(4444);
 
@@ -53,16 +48,11 @@ static tcp::tcp_config::pointer test_conf2(
 class TlsTest : public ::testing::Test {
  public:
   void SetUp() override {
-    g_io_context->restart();
-    pool::load(g_io_context, 0);
     tcp::tcp_async::load();
     tls::initialize();
   }
 
-  void TearDown() override {
-    tcp::tcp_async::unload();
-    pool::unload();
-  }
+  void TearDown() override { tcp::tcp_async::unload(); }
 };
 
 TEST_F(TlsTest, AnonTlsStream) {
@@ -185,7 +175,7 @@ TEST_F(TlsTest, AnonTlsStreamContinuous) {
     tls::stream* tls_centengine =
         static_cast<tls::stream*>(io_tls_centengine.get());
 
-    char str[20];
+    char str[24];
     int i = 0;
 
     /* This is not representative of a real stream. Here we have to call write
@@ -420,7 +410,7 @@ TEST_F(TlsTest, TlsStreamCaError) {
     cbd_finished = true;
   });
 
-  std::thread centengine([&cbd_finished] {
+  std::thread centengine([] {
     auto c{std::make_unique<tcp::connector>(test_conf2)};
 
     /* the name does not match with the CN of the server certificate */
