@@ -1,20 +1,20 @@
 /**
- * Copyright 2013 Centreon
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- *
- * For more information : contact@centreon.com
- */
+* Copyright 2013 Centreon
+*
+* Licensed under the Apache License, Version 2.0 (the "License");
+* you may not use this file except in compliance with the License.
+* You may obtain a copy of the License at
+*
+*     http://www.apache.org/licenses/LICENSE-2.0
+*
+* Unless required by applicable law or agreed to in writing, software
+* distributed under the License is distributed on an "AS IS" BASIS,
+* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+* See the License for the specific language governing permissions and
+* limitations under the License.
+*
+* For more information : contact@centreon.com
+*/
 
 #include "com/centreon/broker/tls2/factory.hh"
 
@@ -41,8 +41,7 @@ using namespace com::centreon::broker::tls2;
  *  is running. We will be able to add this endpoint later, following the ext
  *  value.
  */
-bool factory::has_endpoint(const config::endpoint& cfg,
-                           io::extension* ext) const {
+bool factory::has_endpoint(config::endpoint& cfg, io::extension* ext) {
   if (ext) {
     auto it = cfg.params.find("tls2");
     if (it == cfg.params.end() || absl::EqualsIgnoreCase(it->second, "no"))
@@ -89,10 +88,12 @@ bool factory::has_endpoint(const config::endpoint& cfg,
  *
  *  @return New endpoint object.
  */
-io::endpoint* factory::new_endpoint(config::endpoint& cfg,
-                                    bool& is_acceptor,
-                                    std::shared_ptr<persistent_cache> cache
-                                    [[maybe_unused]]) const {
+io::endpoint* factory::new_endpoint(
+    config::endpoint& cfg,
+    bool& is_acceptor,
+    std::shared_ptr<persistent_cache> cache) const {
+  (void)cache;
+
   // Find TLS parameters (optional).
   bool tls2{false};
   std::string private_key;
