@@ -58,11 +58,11 @@ static std::string const& find_param(config::endpoint const& cfg,
  *
  *  @return true if the configuration matches the unified_sql layer.
  */
-bool factory::has_endpoint(const config::endpoint& cfg,
-                           io::extension* ext) const {
+bool factory::has_endpoint(config::endpoint& cfg, io::extension* ext) {
   if (ext)
     *ext = io::extension("STORAGE", false, false);
-  return absl::EqualsIgnoreCase(cfg.type, "unified_sql");
+  bool is_unified_sql{absl::EqualsIgnoreCase(cfg.type, "unified_sql")};
+  return is_unified_sql;
 }
 
 /**
