@@ -25,7 +25,6 @@
 #include <cstdlib>
 #include <cstring>
 #include <memory>
-#include "com/centreon/exceptions/basic.hh"
 #include "com/centreon/exceptions/msg_fmt.hh"
 #include "com/centreon/logging/logger.hh"
 #include "com/centreon/process_listener.hh"
@@ -195,7 +194,7 @@ void process_manager::_close_stream(int fd) noexcept {
     _update = true;
     std::unordered_map<int, process*>::iterator it(_processes_fd.find(fd));
     if (it == _processes_fd.end())
-      throw basic_error() << "invalid fd: not found in processes fd list";
+      throw exceptions::msg_fmt("invalid fd: not found in processes fd list");
 
     process* p = it->second;
     _processes_fd.erase(it);
@@ -263,7 +262,7 @@ uint32_t process_manager::_read_stream(int fd) noexcept {
       auto it = _processes_fd.find(fd);
       if (it == _processes_fd.end()) {
         _update = true;
-        throw basic_error() << "invalid fd: not found in processes fd list";
+        throw exceptions::msg_fmt("invalid fd: not found in processes fd list");
       }
       p = it->second;
     }
@@ -298,8 +297,9 @@ void process_manager::_run() {
           break;
         else {
           /* After 20s with only orphans pid, we quit if asked. */
-          std::time_t now;
-          std::time(&now);
+          auto now = std::chrono::duration_cast<std::chrono::seconds>(
+                         std::chrono::system_clock::now().time_since_epoch())
+                         .count();
           if (now - _finished_time > 20)
             break;
         }
@@ -312,7 +312,7 @@ void process_manager::_run() {
           ret = 0;
         else {
           const char* msg = strerror(errno);
-          throw basic_error() << "poll failed: " << msg;
+          throw exceptions::msg_fmt("poll failed: {}", msg);
         }
       }
       for (uint32_t i = 0, checked = 0;
