@@ -59,6 +59,25 @@ struct boost_process {
   boost::process::v2::basic_process<asio::io_context::executor_type> proc;
 };
 
+#if defined(BOOST_PROCESS_V2_WINDOWS)
+
+/**
+ * @brief The only goal of this struct is to set CREATE_NO_WINDOW flag in
+ * CreateProcess call. Agent only start console applications, so we ensure that
+ * no parasit cmd windows will be created.
+ */
+struct create_no_window {
+  template <class launcher>
+  boost::system::error_code on_setup(
+      launcher& windows_launcher,
+      const std::filesystem::path& /*executable*/,
+      std::wstring& /*cmd_line*/) {
+    windows_launcher.creation_flags |= CREATE_NO_WINDOW;
+    return {};
+  }
+};
+#endif
+
 }  // namespace com::centreon::common::detail
 
 using namespace com::centreon::common;
@@ -71,7 +90,9 @@ using namespace com::centreon::common;
  * @param logger
  * @param exe_path exe without arguments
  * @param use_setpgid if true, we set process group of child process
- * @param use_stdin if true, we open a stding pipe to child process
+ * @param use_stdin if true, we open a stdin pipe to child process, if false,
+ * we open a stdin pipe, but we close it as soon as child process is created. By
+ * doing this, child process will read an eof.
  * @param args command arguments
  * @param env environment (boost)
  */
@@ -119,8 +140,7 @@ process<use_mutex>::process(
     bool use_setpgid,
     bool use_stdin,
     const process::shared_env& env)
-    : _args(parse_cmd_line(cmd_line)),
-      _use_setpgid(use_setpgid),
+    : _use_setpgid(use_setpgid),
       _use_stdin(use_stdin),
       _env(env),
       _logger(logger),
@@ -129,8 +149,7 @@ process<use_mutex>::process(
       _stdout_pipe(*io_context),
       _stderr_pipe(*io_context),
       _stdin_pipe(*io_context) {
-  SPDLOG_LOGGER_TRACE(_logger, "create process {:p}",
-                      static_cast<const void*>(this));
+  _args = parse_cmd_line(cmd_line);
 }
 
 template <bool use_mutex>
@@ -158,8 +177,6 @@ process_args::pointer process<use_mutex>::parse_cmd_line(
  */
 template <bool use_mutex>
 process<use_mutex>::~process() {
-  SPDLOG_LOGGER_TRACE(_logger, "delete process {:p}",
-                      static_cast<const void*>(this));
   if (_proc) {
     delete _proc;
   }
@@ -172,7 +189,7 @@ process<use_mutex>::~process() {
  * @return int
  */
 template <bool use_mutex>
-int process<use_mutex>::get_pid() const {
+int process<use_mutex>::get_pid() {
   detail::lock<use_mutex> l(&_protect);
   if (_proc) {
     return _proc->proc.id();
@@ -186,51 +203,15 @@ int process<use_mutex>::get_pid() const {
  * we also start an asynchronous read on process fd to be aware of child process
  * termination
  *
- * @param handler handler called at the end of child process
- * @param stdout_handler handler called each time child process write something
- * to stdout
- * @param stderr_handler handler called each time child process write something
- * to stderr
- * @param timeout child process will be called at this end of this timeout, pass
- * {} to avoid it
+ * @param enable_stdin On Windows set it to false if you doesn't want to write
+ * on child stdin
  */
 template <bool use_mutex>
 void process<use_mutex>::start_process(
-    handler_type&& handler,
-    reader_type&& stdout_handler,
-    reader_type&& stderr_handler,
-    const std::chrono::system_clock::duration& timeout) {
-  detail::lock<use_mutex> l(&_protect);
-  _stdout_handler = std::move(stdout_handler);
-  _stderr_handler = std::move(stderr_handler);
-  _start_process_nolock(std::move(handler), timeout);
-}
-
-template <bool use_mutex>
-void process<use_mutex>::start_process(
-    handler_type&& handler,
-    const std::chrono::system_clock::duration& timeout) {
-  detail::lock<use_mutex> l(&_protect);
-  _stdout_handler = reader_type();
-  _stderr_handler = reader_type();
-  _start_process_nolock(std::move(handler), timeout);
-}
-
-/**
- * @brief start a new process, if a previous one is running, it's killed
- * In this function, we start child process and stdout, stderr asynchronous read
- * we also start an asynchronous read on process fd to be aware of child process
- * termination
- *
- * @param handler handler called at the end of child process
- * @param timeout child process will be called at this end of this timeout, pass
- * {} to avoid it
- */
-template <bool use_mutex>
-void process<use_mutex>::_start_process_nolock(
     handler_type&& handler,
     const std::chrono::system_clock::duration& timeout) {
   SPDLOG_LOGGER_DEBUG(_logger, "start process: {}", *_args);
+  detail::lock<use_mutex> l(&_protect);
   _handler = std::move(handler);
 
   if (_completion_flags) {
@@ -272,34 +253,24 @@ static const std::vector<std::string> _no_args;
 template <bool use_mutex>
 void process<use_mutex>::_create_process() {
   if (_env && !_env->env_buffer.empty()) {
-    if (_use_stdin) {
-      _proc = new detail::boost_process(
-          boost::process::v2::basic_process<asio::io_context::executor_type>(
-              *_io_context, _args->get_exe_path(), _args->get_args(),
-              boost::process::v2::process_stdio{_stdin_pipe, _stdout_pipe,
-                                                _stderr_pipe},
-              *_env));
-    } else {
-      _proc = new detail::boost_process(
-          boost::process::v2::basic_process<asio::io_context::executor_type>(
-              *_io_context, _args->get_exe_path(), _args->get_args(),
-              boost::process::v2::process_stdio{{}, _stdout_pipe, _stderr_pipe},
-              *_env));
-    }
+    _proc = new detail::boost_process(
+        boost::process::v2::basic_process<asio::io_context::executor_type>(
+            *_io_context, _args->get_exe_path(), _args->get_args(),
+            boost::process::v2::process_stdio{_stdin_pipe, _stdout_pipe,
+                                              _stderr_pipe},
+            *_env, detail::create_no_window()));
   } else {
-    if (_use_stdin) {
-      _proc = new detail::boost_process(
-          boost::process::v2::basic_process<asio::io_context::executor_type>(
-              *_io_context, _args->get_exe_path(), _args->get_args(),
-              boost::process::v2::process_stdio{_stdin_pipe, _stdout_pipe,
-                                                _stderr_pipe}));
-    } else {
-      _proc = new detail::boost_process(
-          boost::process::v2::basic_process<asio::io_context::executor_type>(
-              *_io_context, _args->get_exe_path(), _args->get_args(),
-              boost::process::v2::process_stdio{
-                  {}, _stdout_pipe, _stderr_pipe}));
-    }
+    _proc = new detail::boost_process(
+        boost::process::v2::basic_process<asio::io_context::executor_type>(
+            *_io_context, _args->get_exe_path(), _args->get_args(),
+            boost::process::v2::process_stdio{_stdin_pipe, _stdout_pipe,
+                                              _stderr_pipe},
+            detail::create_no_window()));
+  }
+  if (!_use_stdin) {  // we don't want a stdin for child process => stdin read
+                      // from child process will get an eof
+    boost::system::error_code ec;
+    _stdin_pipe.close(ec);
   }
 }
 
@@ -315,17 +286,15 @@ void process<use_mutex>::_create_process() {
   char* const* env = (_env && !_env->env_buffer.empty())
                          ? const_cast<char* const*>(_env->env.data())
                          : nullptr;
-  if (_use_stdin) {
-    _proc = new detail::boost_process(detail::spawnp(
-        *_io_context, _args, _use_setpgid,
-        proc::detail::process_input_binding(_stdin_pipe).fd,
-        proc::detail::process_output_binding(_stdout_pipe).fd,
-        proc::detail::process_error_binding(_stderr_pipe).fd, env));
-  } else {
-    _proc = new detail::boost_process(detail::spawnp(
-        *_io_context, _args, _use_setpgid, -1,
-        proc::detail::process_output_binding(_stdout_pipe).fd,
-        proc::detail::process_error_binding(_stderr_pipe).fd, env));
+  _proc = new detail::boost_process(detail::spawnp(
+      *_io_context, _args, _use_setpgid,
+      proc::detail::process_input_binding(_stdin_pipe).fd,
+      proc::detail::process_output_binding(_stdout_pipe).fd,
+      proc::detail::process_error_binding(_stderr_pipe).fd, env));
+  if (!_use_stdin) {  // we don't want a stdin for child process => stdin read
+                      // from child process will get an eof
+    boost::system::error_code ec;
+    _stdin_pipe.close(ec);
   }
 }
 
@@ -478,14 +447,12 @@ template <bool use_mutex>
 void process<use_mutex>::_on_stdout_read(const boost::system::error_code& err,
                                          size_t nb_read) {
   bool eof = false;
-  std::string received;
   {
     detail::lock<use_mutex> l(&_protect);
     if (err) {
       if (err == asio::error::eof || err == asio::error::broken_pipe) {
-        SPDLOG_LOGGER_DEBUG(_logger,
-                            "pid:{} end read from stdout of process {}: {}",
-                            _proc->proc.handle().id(), *_args, err.message());
+        SPDLOG_LOGGER_DEBUG(_logger, "fail read from stdout of process {}: {}",
+                            *_args, err.message());
       } else {
         SPDLOG_LOGGER_ERROR(_logger,
                             "fail read from stdout of process {}: {} {}",
@@ -496,18 +463,10 @@ void process<use_mutex>::_on_stdout_read(const boost::system::error_code& err,
     } else {
       SPDLOG_LOGGER_TRACE(_logger, " process: {} read from stdout: {}", *_args,
                           std::string_view(_stdout_read_buffer, nb_read));
-      if (!_stdout_handler) {
-        _stdout.append(_stdout_read_buffer, nb_read);
-      } else {
-        received.assign(_stdout_read_buffer, nb_read);
-      }
+      _stdout.append(_stdout_read_buffer, nb_read);
       _stdout_read();
     }
   }
-  if (!received.empty()) {
-    _stdout_handler(received);
-  }
-
   if (eof) {
     _on_completion();
   }
@@ -548,14 +507,12 @@ template <bool use_mutex>
 void process<use_mutex>::_on_stderr_read(const boost::system::error_code& err,
                                          size_t nb_read) {
   bool eof = false;
-  std::string received;
   {
     detail::lock<use_mutex> l(&_protect);
     if (err) {
       if (err == asio::error::eof || err == asio::error::broken_pipe) {
-        SPDLOG_LOGGER_DEBUG(_logger,
-                            "pid:{} end read from stderr of process {}: {}",
-                            _proc->proc.handle().id(), *_args, err.message());
+        SPDLOG_LOGGER_DEBUG(_logger, "fail read from stderr of process {}: {}",
+                            *_args, err.message());
       } else {
         SPDLOG_LOGGER_ERROR(_logger,
                             "fail read from stderr of process {}: {} {}",
@@ -566,19 +523,10 @@ void process<use_mutex>::_on_stderr_read(const boost::system::error_code& err,
     } else {
       SPDLOG_LOGGER_TRACE(_logger, " process: {} read from stdout: {}", *_args,
                           std::string_view(_stderr_read_buffer, nb_read));
-      if (!_stderr_handler) {
-        _stderr.append(_stderr_read_buffer, nb_read);
-      } else {
-        received.assign(_stderr_read_buffer, nb_read);
-      }
+      _stderr.append(_stderr_read_buffer, nb_read);
       _stderr_read();
     }
   }
-
-  if (!received.empty()) {
-    _stderr_handler(received);
-  }
-
   if (eof) {
     _on_completion();
   }
@@ -646,4 +594,4 @@ template class process<true>;
 
 template class process<false>;
 
-}  // namespace com::centreon::common
+}  // namespace com::centreon::common
\ No newline at end of file
