@@ -1,7 +1,7 @@
 /**
  * Copyright 2002-2010      Ethan Galstad
  * Copyright 2010           Nagios Core Development Team
- * Copyright 2011-2013,2020 Centreon
+ * Copyright 2011-2013,2020-2024 Centreon
  *
  * This file is part of Centreon Engine.
  *
@@ -54,8 +54,13 @@ void broker_acknowledgement_data(
     int notify_contacts,
     int persistent_comment) {
   // Config check.
+#ifdef LEGACY_CONF
   if (!(config->event_broker_options() & BROKER_ACKNOWLEDGEMENT_DATA))
     return;
+#else
+  if (!(pb_config.event_broker_options() & BROKER_ACKNOWLEDGEMENT_DATA))
+    return;
+#endif
 
   // Fill struct with relevant data.
   host* temp_host(NULL);
@@ -122,8 +127,13 @@ void broker_adaptive_contact_data(
  */
 void broker_adaptive_severity_data(int type, void* data) {
   /* Config check. */
+#ifdef LEGACY_CONF
   if (!(config->event_broker_options() & BROKER_ADAPTIVE_DATA))
     return;
+#else
+  if (!(pb_config.event_broker_options() & BROKER_ADAPTIVE_DATA))
+    return;
+#endif
 
   /* Fill struct with relevant data. */
   nebstruct_adaptive_severity_data ds;
@@ -142,8 +152,13 @@ void broker_adaptive_severity_data(int type, void* data) {
  */
 void broker_adaptive_tag_data(int type, void* data) {
   /* Config check. */
+#ifdef LEGACY_CONF
   if (!(config->event_broker_options() & BROKER_ADAPTIVE_DATA))
     return;
+#else
+  if (!(pb_config.event_broker_options() & BROKER_ADAPTIVE_DATA))
+    return;
+#endif
 
   /* Fill struct with relevant data. */
   nebstruct_adaptive_tag_data ds;
@@ -162,8 +177,13 @@ void broker_adaptive_tag_data(int type, void* data) {
  */
 void broker_adaptive_dependency_data(int type, void* data) {
   // Config check.
+#ifdef LEGACY_CONF
   if (!(config->event_broker_options() & BROKER_ADAPTIVE_DATA))
     return;
+#else
+  if (!(pb_config.event_broker_options() & BROKER_ADAPTIVE_DATA))
+    return;
+#endif
 
   // Fill struct with relevant data.
   nebstruct_adaptive_dependency_data ds;
@@ -205,8 +225,13 @@ void broker_adaptive_host_data(int type,
                                host* hst,
                                unsigned long modattr) {
   // Config check.
+#ifdef LEGACY_CONF
   if (!(config->event_broker_options() & BROKER_ADAPTIVE_DATA))
     return;
+#else
+  if (!(pb_config.event_broker_options() & BROKER_ADAPTIVE_DATA))
+    return;
+#endif
 
   // Fill struct with relevant data.
   nebstruct_adaptive_host_data ds;
@@ -259,8 +284,13 @@ void broker_adaptive_service_data(int type,
                                   com::centreon::engine::service* svc,
                                   unsigned long modattr) {
   // Config check.
+#ifdef LEGACY_CONF
   if (!(config->event_broker_options() & BROKER_ADAPTIVE_DATA))
     return;
+#else
+  if (!(pb_config.event_broker_options() & BROKER_ADAPTIVE_DATA))
+    return;
+#endif
 
   // Fill struct with relevant data.
   nebstruct_adaptive_service_data ds;
@@ -353,8 +383,13 @@ void broker_comment_data(int type,
                          time_t expire_time,
                          unsigned long comment_id) {
   // Config check.
+#ifdef LEGACY_CONF
   if (!(config->event_broker_options() & BROKER_COMMENT_DATA))
     return;
+#else
+  if (!(pb_config.event_broker_options() & BROKER_COMMENT_DATA))
+    return;
+#endif
 
   // Fill struct with relevant data.
   nebstruct_comment_data ds;
@@ -455,8 +490,13 @@ int broker_contact_notification_method_data(
  */
 void broker_contact_status(int type, contact* cntct) {
   // Config check.
+#ifdef LEGACY_CONF
   if (!(config->event_broker_options() & BROKER_STATUS_DATA))
     return;
+#else
+  if (!(pb_config.event_broker_options() & BROKER_STATUS_DATA))
+    return;
+#endif
 
   // Fill struct with relevant data.
   nebstruct_service_status_data ds;
@@ -478,20 +518,26 @@ void broker_contact_status(int type, contact* cntct) {
  */
 void broker_custom_variable(int type,
                             void* data,
-                            char const* varname,
-                            char const* varvalue,
+                            std::string_view&& varname,
+                            std::string_view&& varvalue,
                             struct timeval const* timestamp) {
   // Config check.
+#ifdef LEGACY_CONF
   if (!(config->event_broker_options() & BROKER_CUSTOMVARIABLE_DATA))
     return;
+#else
+  if (!(pb_config.event_broker_options() & BROKER_CUSTOMVARIABLE_DATA))
+    return;
+#endif
 
   // Fill struct with relevant data.
-  nebstruct_custom_variable_data ds;
-  ds.type = type;
-  ds.timestamp = get_broker_timestamp(timestamp);
-  ds.object_ptr = data;
-  ds.var_name = const_cast<char*>(varname);
-  ds.var_value = const_cast<char*>(varvalue);
+  nebstruct_custom_variable_data ds{
+      .type = type,
+      .timestamp = get_broker_timestamp(timestamp),
+      .var_name = varname,
+      .var_value = varvalue,
+      .object_ptr = data,
+  };
 
   // Make callback.
   neb_make_callbacks(NEBCALLBACK_CUSTOM_VARIABLE_DATA, &ds);
@@ -532,8 +578,13 @@ void broker_downtime_data(int type,
                           unsigned long downtime_id,
                           struct timeval const* timestamp) {
   // Config check.
+#ifdef LEGACY_CONF
   if (!(config->event_broker_options() & BROKER_DOWNTIME_DATA))
     return;
+#else
+  if (!(pb_config.event_broker_options() & BROKER_DOWNTIME_DATA))
+    return;
+#endif
 
   // Fill struct with relevant data.
   nebstruct_downtime_data ds;
@@ -570,8 +621,13 @@ void broker_external_command(int type,
                              char* command_args,
                              struct timeval const* timestamp) {
   // Config check.
+#ifdef LEGACY_CONF
   if (!(config->event_broker_options() & BROKER_EXTERNALCOMMAND_DATA))
     return;
+#else
+  if (!(pb_config.event_broker_options() & BROKER_EXTERNALCOMMAND_DATA))
+    return;
+#endif
 
   // Fill struct with relevant data.
   nebstruct_external_command_data ds;
@@ -593,8 +649,13 @@ void broker_external_command(int type,
  */
 void broker_group(int type, void* data) {
   // Config check.
+#ifdef LEGACY_CONF
   if (!(config->event_broker_options() & BROKER_GROUP_DATA))
     return;
+#else
+  if (!(pb_config.event_broker_options() & BROKER_GROUP_DATA))
+    return;
+#endif
 
   // Fill struct with relevant data.
   nebstruct_group_data ds;
@@ -614,8 +675,13 @@ void broker_group(int type, void* data) {
  */
 void broker_group_member(int type, void* object, void* group) {
   // Config check.
+#ifdef LEGACY_CONF
   if (!(config->event_broker_options() & BROKER_GROUP_MEMBER_DATA))
     return;
+#else
+  if (!(pb_config.event_broker_options() & BROKER_GROUP_MEMBER_DATA))
+    return;
+#endif
 
   // Fill struct will relevant data.
   nebstruct_group_member_data ds;
@@ -644,8 +710,13 @@ int broker_host_check(int type,
                       char const* cmdline,
                       char* output) {
   // Config check.
+#ifdef LEGACY_CONF
   if (!(config->event_broker_options() & BROKER_HOST_CHECKS))
     return OK;
+#else
+  if (!(pb_config.event_broker_options() & BROKER_HOST_CHECKS))
+    return OK;
+#endif
   if (!hst)
     return ERROR;
 
@@ -675,8 +746,13 @@ int broker_host_check(int type,
  */
 void broker_host_status(int type, host* hst, uint32_t attributes) {
   // Config check.
+#ifdef LEGACY_CONF
   if (!(config->event_broker_options() & BROKER_STATUS_DATA))
     return;
+#else
+  if (!(pb_config.event_broker_options() & BROKER_STATUS_DATA))
+    return;
+#endif
 
   // Fill struct with relevant data.
   nebstruct_host_status_data ds;
@@ -696,9 +772,15 @@ void broker_host_status(int type, host* hst, uint32_t attributes) {
  */
 void broker_log_data(char* data, time_t entry_time) {
   // Config check.
+#ifdef LEGACY_CONF
   if (!(config->event_broker_options() & BROKER_LOGGED_DATA) ||
       !config->log_legacy_enabled())
     return;
+#else
+  if (!(pb_config.event_broker_options() & BROKER_LOGGED_DATA) ||
+      !pb_config.log_legacy_enabled())
+    return;
+#endif
 
   // Fill struct with relevant data.
   nebstruct_log_data ds;
@@ -752,8 +834,13 @@ int broker_notification_data(int type [[maybe_unused]],
  */
 void broker_program_state(int type, int flags) {
   // Config check.
+#ifdef LEGACY_CONF
   if (!(config->event_broker_options() & BROKER_PROGRAM_STATE))
     return;
+#else
+  if (!(pb_config.event_broker_options() & BROKER_PROGRAM_STATE))
+    return;
+#endif
 
   // Fill struct with relevant data.
   nebstruct_process_data ds;
@@ -768,6 +855,7 @@ void broker_program_state(int type, int flags) {
  *  Sends program status updates to broker.
  */
 void broker_program_status() {
+#ifdef LEGACY_CONF
   // Config check.
   if (!(config->event_broker_options() & BROKER_STATUS_DATA))
     return;
@@ -789,6 +877,29 @@ void broker_program_status() {
 
   // Make callbacks.
   neb_make_callbacks(NEBCALLBACK_PROGRAM_STATUS_DATA, &ds);
+#else
+  // Config check.
+  if (!(pb_config.event_broker_options() & BROKER_STATUS_DATA))
+    return;
+
+  // Fill struct with relevant data.
+  nebstruct_program_status_data ds;
+  ds.last_command_check = last_command_check;
+  ds.notifications_enabled = pb_config.enable_notifications();
+  ds.active_service_checks_enabled = pb_config.execute_service_checks();
+  ds.passive_service_checks_enabled = pb_config.accept_passive_service_checks();
+  ds.active_host_checks_enabled = pb_config.execute_host_checks();
+  ds.passive_host_checks_enabled = pb_config.accept_passive_host_checks();
+  ds.event_handlers_enabled = pb_config.enable_event_handlers();
+  ds.flap_detection_enabled = pb_config.enable_flap_detection();
+  ds.obsess_over_hosts = pb_config.obsess_over_hosts();
+  ds.obsess_over_services = pb_config.obsess_over_services();
+  ds.global_host_event_handler = pb_config.global_host_event_handler();
+  ds.global_service_event_handler = pb_config.global_service_event_handler();
+
+  // Make callbacks.
+  neb_make_callbacks(NEBCALLBACK_PROGRAM_STATUS_DATA, &ds);
+#endif
 }
 
 /**
@@ -806,8 +917,13 @@ void broker_relation_data(int type,
                           host* dep_hst,
                           com::centreon::engine::service* dep_svc) {
   // Config check.
+#ifdef LEGACY_CONF
   if (!(config->event_broker_options() & BROKER_RELATION_DATA))
     return;
+#else
+  if (!(pb_config.event_broker_options() & BROKER_RELATION_DATA))
+    return;
+#endif
   if (!hst || !dep_hst)
     return;
 
@@ -852,8 +968,13 @@ int broker_service_check(int type,
                          int check_type,
                          const char* cmdline) {
   // Config check.
+#ifdef LEGACY_CONF
   if (!(config->event_broker_options() & BROKER_SERVICE_CHECKS))
     return OK;
+#else
+  if (!(pb_config.event_broker_options() & BROKER_SERVICE_CHECKS))
+    return OK;
+#endif
   if (!svc)
     return ERROR;
 
@@ -885,8 +1006,13 @@ void broker_service_status(int type,
                            com::centreon::engine::service* svc,
                            uint32_t attributes) {
   // Config check.
+#ifdef LEGACY_CONF
   if (!(config->event_broker_options() & BROKER_STATUS_DATA))
     return;
+#else
+  if (!(pb_config.event_broker_options() & BROKER_STATUS_DATA))
+    return;
+#endif
 
   // Fill struct with relevant data.
   nebstruct_service_status_data ds;
@@ -924,6 +1050,36 @@ void broker_statechange_data(int type __attribute__((unused)),
                              struct timeval const* timestamp
                              __attribute__((unused))) {}
 
+/**
+ *  Send system command data to broker.
+ *
+ *  @param[in] type          Type.
+ *  @param[in] flags         Flags.
+ *  @param[in] attr          Attributes.
+ *  @param[in] start_time    Start time.
+ *  @param[in] end_time      End time.
+ *  @param[in] exectime      Execution time.
+ *  @param[in] timeout       Timeout.
+ *  @param[in] early_timeout Early timeout.
+ *  @param[in] retcode       Return code.
+ *  @param[in] cmd           Command.
+ *  @param[in] output        Output.
+ *  @param[in] timestamp     Timestamp.
+ */
+void broker_system_command(int type __attribute__((unused)),
+                           int flags __attribute__((unused)),
+                           int attr __attribute__((unused)),
+                           struct timeval start_time __attribute__((unused)),
+                           struct timeval end_time __attribute__((unused)),
+                           double exectime __attribute__((unused)),
+                           int timeout __attribute__((unused)),
+                           int early_timeout __attribute__((unused)),
+                           int retcode __attribute__((unused)),
+                           const char* cmd __attribute__((unused)),
+                           const char* output __attribute__((unused)),
+                           struct timeval const* timestamp
+                           __attribute__((unused))) {}
+
 /**
  *  Send timed event data to broker.
  *
@@ -968,4 +1124,15 @@ void broker_bench(unsigned id,
   // Make callbacks.
   neb_make_callbacks(NEBCALLBACK_BENCH_DATA, &ds);
 }
+
+/**
+ * @brief send agent usage statistics to broker
+ *
+ * @param stats
+ */
+void broker_agent_stats(nebstruct_agent_stats_data& stats) {
+  // Fill struct with relevant data.
+  // Make callbacks.
+  neb_make_callbacks(NEBCALLBACK_AGENT_STATS, &stats);
+}
 }
