@@ -1,47 +1,44 @@
 /**
- * Copyright 2024 Centreon
+ * Copyright 1999-2010 Ethan Galstad
+ * Copyright 2011-2024 Centreon
  *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * This file is part of Centreon Engine.
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ * Centreon Engine is free software: you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License version 2
+ * as published by the Free Software Foundation.
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Centreon Engine is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
  *
- * For more information : contact@centreon.com
+ * You should have received a copy of the GNU General Public License
+ * along with Centreon Engine. If not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #include "com/centreon/engine/checks/checker.hh"
 
 #include "com/centreon/engine/broker.hh"
+#include "com/centreon/engine/checkable.hh"
 #include "com/centreon/engine/configuration/whitelist.hh"
 #include "com/centreon/engine/exceptions/error.hh"
 #include "com/centreon/engine/globals.hh"
+#include "com/centreon/engine/logging/logger.hh"
 #include "com/centreon/engine/macros.hh"
 #include "com/centreon/engine/neberrors.hh"
 #include "com/centreon/engine/objects.hh"
 #include "com/centreon/engine/shared.hh"
 #include "com/centreon/engine/string.hh"
-#include "com/centreon/exceptions/interruption.hh"
 
 using namespace com::centreon;
 using namespace com::centreon::engine::logging;
 using namespace com::centreon::engine::checks;
 
-std::shared_ptr<checker> checker::_instance;
+checker* checker::_instance = nullptr;
 static constexpr time_t max_check_reaper_time = 30;
 
-/**************************************
- *                                     *
- *           Public Methods            *
- *                                     *
- **************************************/
-
 /**
  *  Get instance of the checker singleton.
  *
@@ -56,11 +53,14 @@ checker& checker::instance() {
 
 void checker::init(bool used_by_test) {
   if (!_instance)
-    _instance = std::make_shared<checker>(used_by_test);
+    _instance = new checker(used_by_test);
 }
 
 void checker::deinit() {
-  _instance.reset();
+  if (_instance) {
+    delete _instance;
+    _instance = nullptr;
+  }
 }
 
 void checker::clear() noexcept {
@@ -328,6 +328,11 @@ void checker::run_sync(host* hst,
       << "* Sync host check done: new state=" << hst->get_current_state();
   SPDLOG_LOGGER_DEBUG(checks_logger, "* Sync host check done: new state={}",
                       static_cast<uint32_t>(hst->get_current_state()));
+
+  // Send event broker.
+  broker_host_check(NEBTYPE_HOSTCHECK_PROCESSED, hst, checkable::check_active,
+                    nullptr,
+                    const_cast<char*>(hst->get_plugin_output().c_str()));
 }
 
 /**************************************
@@ -340,18 +345,13 @@ void checker::run_sync(host* hst,
  *  Default constructor.
  */
 checker::checker(bool used_by_test)
-    : commands::command_listener(), _used_by_test(used_by_test) {
-  SPDLOG_LOGGER_DEBUG(commands_logger, "create checker {:p}",
-                      static_cast<const void*>(this));
-}
+    : commands::command_listener(), _used_by_test(used_by_test) {}
 
 /**
  *  Default destructor.
  */
-checker::~checker() {
+checker::~checker() noexcept {
   clear();
-  SPDLOG_LOGGER_DEBUG(commands_logger, "delete checker {:p}",
-                      static_cast<const void*>(this));
 }
 
 /**
@@ -384,10 +384,10 @@ void checker::finished(commands::result const& res) noexcept {
                        .tv_usec = res.end_time.to_useconds() % 1000000ll};
 
   result->set_finish_time(tv);
-  result->set_early_timeout(res.exit_status == common::e_exit_status::timeout);
+  result->set_early_timeout(res.exit_status == process::timeout);
   result->set_return_code(res.exit_code);
-  result->set_exited_ok(res.exit_status == common::e_exit_status::normal ||
-                        res.exit_status == common::e_exit_status::timeout);
+  result->set_exited_ok(res.exit_status == process::normal ||
+                        res.exit_status == process::timeout);
   result->set_output(res.output);
 
   // Queue check result.
@@ -448,6 +448,12 @@ com::centreon::engine::host::host_state checker::_execute_sync(host* hst) {
   // Send broker event.
   timeval start_time{0, 0};
   timeval end_time{0, 0};
+  int ret(broker_host_check(NEBTYPE_HOSTCHECK_SYNC_PRECHECK, hst,
+                            checkable::check_active, nullptr, nullptr));
+
+  // Host sync check was cancelled or overriden by NEB module.
+  if ((NEBERROR_CALLBACKCANCEL == ret) || (NEBERROR_CALLBACKOVERRIDE == ret))
+    return hst->get_current_state();
 
   // Get current host macros.
   nagios_macros* macros(get_global_macros());
@@ -465,6 +471,12 @@ com::centreon::engine::host::host_state checker::_execute_sync(host* hst) {
   // Get command object.
   commands::command::pointer cmd = hst->get_check_command_ptr();
   std::string processed_cmd(cmd->process_cmd(macros));
+  const char* tmp_processed_cmd = processed_cmd.c_str();
+
+  // Send broker event.
+  broker_host_check(NEBTYPE_HOSTCHECK_RAW_START, hst, checkable::check_active,
+                    processed_cmd.c_str(),
+                    const_cast<char*>(hst->get_plugin_output().c_str()));
 
   // Debug messages.
   engine_logger(dbg_commands, more)
@@ -483,6 +495,22 @@ com::centreon::engine::host::host_state checker::_execute_sync(host* hst) {
   hst->set_long_plugin_output("");
   hst->set_perf_data("");
 
+  // Send broker event.
+  timeval start_cmd;
+  timeval end_cmd{0, 0};
+  gettimeofday(&start_cmd, nullptr);
+#ifdef LEGACY_CONF
+  broker_system_command(NEBTYPE_SYSTEM_COMMAND_START, NEBFLAG_NONE,
+                        NEBATTR_NONE, start_cmd, end_cmd, 0,
+                        config->host_check_timeout(), false, 0,
+                        tmp_processed_cmd, nullptr, nullptr);
+#else
+  broker_system_command(NEBTYPE_SYSTEM_COMMAND_START, NEBFLAG_NONE,
+                        NEBATTR_NONE, start_cmd, end_cmd, 0,
+                        pb_config.host_check_timeout(), false, 0,
+                        tmp_processed_cmd, nullptr, nullptr);
+#endif
+
   commands::result res;
 
   auto run_failure = [&](const std::string& reason) {
@@ -490,7 +518,7 @@ com::centreon::engine::host::host_state checker::_execute_sync(host* hst) {
     res.command_id = 0;
     res.end_time = timestamp::now();
     res.exit_code = service::state_unknown;
-    res.exit_status = common::e_exit_status::normal;
+    res.exit_status = process::normal;
     res.output = reason;
     res.start_time = res.end_time;
   };
@@ -509,7 +537,11 @@ com::centreon::engine::host::host_state checker::_execute_sync(host* hst) {
   } else {
     // Run command.
     try {
+#ifdef LEGACY_CONF
       cmd->run(processed_cmd, *macros, config->host_check_timeout(), res);
+#else
+      cmd->run(processed_cmd, *macros, pb_config.host_check_timeout(), res);
+#endif
     } catch (std::exception const& e) {
       run_failure("(Execute command failed)");
 
@@ -526,22 +558,49 @@ com::centreon::engine::host::host_state checker::_execute_sync(host* hst) {
   if (res.end_time >= res.start_time)
     execution_time = res.end_time.to_seconds() - res.start_time.to_seconds();
 
+  // Send broker event.
+  memset(&start_cmd, 0, sizeof(start_time));
+  start_cmd.tv_sec = res.start_time.to_seconds();
+  start_cmd.tv_usec =
+      res.start_time.to_useconds() - start_cmd.tv_sec * 1000000ull;
+  memset(&end_cmd, 0, sizeof(end_time));
+  end_cmd.tv_sec = res.end_time.to_seconds();
+  end_cmd.tv_usec = res.end_time.to_useconds() - end_cmd.tv_sec * 1000000ull;
+#ifdef LEGACY_CONF
+  broker_system_command(NEBTYPE_SYSTEM_COMMAND_END, NEBFLAG_NONE, NEBATTR_NONE,
+                        start_cmd, end_cmd, execution_time,
+                        config->host_check_timeout(),
+                        res.exit_status == process::timeout, res.exit_code,
+                        tmp_processed_cmd, res.output.c_str(), nullptr);
+#else
+  broker_system_command(NEBTYPE_SYSTEM_COMMAND_END, NEBFLAG_NONE, NEBATTR_NONE,
+                        start_cmd, end_cmd, execution_time,
+                        pb_config.host_check_timeout(),
+                        res.exit_status == process::timeout, res.exit_code,
+                        tmp_processed_cmd, res.output.c_str(), nullptr);
+#endif
+
   // Cleanup.
   clear_volatile_macros_r(macros);
 
   // If the command timed out.
-  if (res.exit_status == common::e_exit_status::timeout) {
+#ifdef LEGACY_CONF
+  uint32_t host_check_timeout = config->host_check_timeout();
+#else
+  uint32_t host_check_timeout = pb_config.host_check_timeout();
+#endif
+  if (res.exit_status == process::timeout) {
     res.output = fmt::format("Host check timed out after {}  seconds",
-                             config->host_check_timeout());
+                             host_check_timeout);
     engine_logger(log_runtime_warning, basic)
         << "Warning: Host check command '" << processed_cmd << "' for host '"
-        << hst->name() << "' timed out after " << config->host_check_timeout()
+        << hst->name() << "' timed out after " << host_check_timeout
         << " seconds";
     SPDLOG_LOGGER_WARN(
         runtime_logger,
         "Warning: Host check command '{}' for host '{}' timed out after {} "
         "seconds",
-        processed_cmd, hst->name(), config->host_check_timeout());
+        processed_cmd, hst->name(), host_check_timeout);
   }
 
   // Update values.
@@ -586,6 +645,11 @@ com::centreon::engine::host::host_state checker::_execute_sync(host* hst) {
   // Get the end time of command.
   gettimeofday(&end_time, nullptr);
 
+  // Send broker event.
+  broker_host_check(NEBTYPE_HOSTCHECK_RAW_END, hst, checkable::check_active,
+                    tmp_processed_cmd,
+                    const_cast<char*>(hst->get_plugin_output().c_str()));
+
   // Termination.
   engine_logger(dbg_checks, basic)
       << "** Sync host check done: state=" << return_result;
