@@ -37,7 +37,7 @@ using namespace com::centreon::engine::commands;
  */
 raw::raw(std::string const& name,
          std::string const& command_line,
-         const std::shared_ptr<command_listener>& listener)
+         command_listener* listener)
     : command(name, command_line, listener, e_type::raw), process_listener() {
   if (_command_line.empty())
     throw engine_error() << "Could not create '" << _name
@@ -187,13 +187,13 @@ void raw::run(std::string const& processed_cmd,
   res.start_time = p.start_time();
   res.end_time = p.end_time();
   res.exit_code = p.exit_code();
-  res.exit_status = static_cast<common::e_exit_status>(p.exit_status());
+  res.exit_status = p.exit_status();
 
-  if (res.exit_status == common::e_exit_status::timeout) {
+  if (res.exit_status == process::timeout) {
     res.exit_code = service::state_unknown;
     res.output = "(Process Timeout)";
-  } else if (res.exit_status == common::e_exit_status::crash ||
-             res.exit_code < -1 || res.exit_code > 3)
+  } else if (res.exit_status == process::crash || res.exit_code < -1 ||
+             res.exit_code > 3)
     res.exit_code = service::state_unknown;
 
   engine_logger(dbg_commands, basic) << "raw::run: end process: "
@@ -300,13 +300,13 @@ void raw::finished(process& p) noexcept {
     res.start_time = p.start_time();
     res.end_time = p.end_time();
     res.exit_code = p.exit_code();
-    res.exit_status = static_cast<common::e_exit_status>(p.exit_status());
+    res.exit_status = p.exit_status();
 
-    if (res.exit_status == common::e_exit_status::timeout) {
+    if (res.exit_status == process::timeout) {
       res.exit_code = service::state_unknown;
       res.output = "(Process Timeout)";
-    } else if ((res.exit_status == common::e_exit_status::crash) ||
-               (res.exit_code < -1) || (res.exit_code > 3))
+    } else if ((res.exit_status == process::crash) || (res.exit_code < -1) ||
+               (res.exit_code > 3))
       res.exit_code = service::state_unknown;
 
     engine_logger(dbg_commands, basic)
@@ -480,7 +480,12 @@ void raw::_build_custom_service_macro_environment(nagios_macros& macros,
  *  @param[out]    env     The environment to fill.
  */
 void raw::_build_environment_macros(nagios_macros& macros, environment& env) {
-  if (config->enable_environment_macros()) {
+#ifdef LEGACY_CONF
+  bool enable_environment_macros = config->enable_environment_macros();
+#else
+  bool enable_environment_macros = pb_config.enable_environment_macros();
+#endif
+  if (enable_environment_macros) {
     _build_macrosx_environment(macros, env);
     _build_argv_macro_environment(macros, env);
     _build_custom_host_macro_environment(macros, env);
@@ -497,15 +502,20 @@ void raw::_build_environment_macros(nagios_macros& macros, environment& env) {
  *  @param[out]    env     The environment to fill.
  */
 void raw::_build_macrosx_environment(nagios_macros& macros, environment& env) {
-  for (uint32_t i(0); i < MACRO_X_COUNT; ++i) {
+#ifdef LEGACY_CONF
+  bool use_large_installation_tweaks = config->use_large_installation_tweaks();
+#else
+  bool use_large_installation_tweaks =
+      pb_config.use_large_installation_tweaks();
+#endif
+  for (uint32_t i = 0; i < MACRO_X_COUNT; ++i) {
     int release_memory(0);
 
     // Need to grab macros?
     if (macros.x[i].empty()) {
       // Skip summary macro in lage instalation tweaks.
-      if ((i < MACRO_TOTALHOSTSUP) ||
-          (i > MACRO_TOTALSERVICEPROBLEMSUNHANDLED) ||
-          !config->use_large_installation_tweaks()) {
+      if (i < MACRO_TOTALHOSTSUP || i > MACRO_TOTALSERVICEPROBLEMSUNHANDLED ||
+          !use_large_installation_tweaks) {
         grab_macrox_value_r(&macros, i, "", "", macros.x[i], &release_memory);
       }
     }
@@ -537,11 +547,15 @@ process* raw::_get_free_process() {
   if (_processes_free.empty()) {
     /* Only the out stream is open */
     process* p = new process(this, false, true, false);
+#ifdef LEGACY_CONF
     p->setpgid_on_exec(config->use_setpgid());
+#else
+    p->setpgid_on_exec(pb_config.use_setpgid());
+#endif
     return p;
   }
   // Get a free process.
-  process* p(_processes_free.front());
+  process* p = _processes_free.front();
   _processes_free.pop_front();
   return p;
 }
