@@ -39,12 +39,10 @@ using namespace com::centreon::engine::commands;
 raw_v2::raw_v2(const std::shared_ptr<asio::io_context> io_context,
                std::string const& name,
                std::string const& command_line,
-               const std::shared_ptr<command_listener>& listener)
+               command_listener* listener)
     : command(name, command_line, listener, e_type::raw),
       _io_context(io_context),
       _commands_logger(commands_logger) {
-  SPDLOG_LOGGER_TRACE(commands_logger, "create raw_v2 {:p}",
-                      static_cast<const void*>(this));
   if (_command_line.empty()) {
     throw exceptions::msg_fmt(
         "Could not create {}'' command: command line is empty", _name);
@@ -56,8 +54,6 @@ raw_v2::raw_v2(const std::shared_ptr<asio::io_context> io_context,
  *
  */
 raw_v2::~raw_v2() {
-  SPDLOG_LOGGER_TRACE(commands_logger, "delete raw_v2 {:p}",
-                      static_cast<const void*>(this));
   for (std::shared_ptr<com::centreon::common::process<true>> to_kill :
        _running) {
     _commands_logger->debug("raw_v2::~raw_v2: killing process for command '{}'",
@@ -205,7 +201,12 @@ static void _build_custom_service_macro_environment(
 static void _build_macrosx_environment(
     nagios_macros& macros,
     boost::process::v2::process_environment& env) {
+#ifdef LEGACY_CONF
   bool use_large_installation_tweaks = config->use_large_installation_tweaks();
+#else
+  bool use_large_installation_tweaks =
+      pb_config.use_large_installation_tweaks();
+#endif
   std::string key;
   for (uint32_t i = 0; i < MACRO_X_COUNT; ++i) {
     int release_memory(0);
@@ -244,7 +245,11 @@ static std::vector<std::pair<std::string, std::string>> _empty_args;
  */
 void _build_environment_macros(nagios_macros& macros,
                                boost::process::v2::process_environment& env) {
+#ifdef LEGACY_CONF
   bool enable_environment_macros = config->enable_environment_macros();
+#else
+  bool enable_environment_macros = pb_config.enable_environment_macros();
+#endif
   if (enable_environment_macros) {
     _build_macrosx_environment(macros, env);
     _build_argv_macro_environment(macros, env);
@@ -330,9 +335,8 @@ uint64_t raw_v2::run(const std::string& processed_cmd,
     // exit called by pool thread
     new_process->start_process(
         [me = weak_from_this(), command_id, start = time(nullptr)](
-            const common::process<true>& proc, int exit_code,
-            common::e_exit_status exit_status, const std::string& std_out,
-            const std::string& std_err) {
+            const common::process<true>& proc, int exit_code, int exit_status,
+            const std::string& std_out, const std::string& std_err) {
           std::shared_ptr<raw_v2> parent =
               std::static_pointer_cast<raw_v2>(me.lock());
           if (parent) {
@@ -376,7 +380,7 @@ void raw_v2::_on_complete(const common::process<true>& proc,
                           uint64_t command_id,
                           time_t start,
                           int exit_code,
-                          common::e_exit_status exit_status,
+                          int exit_status,
                           const std::string& std_out,
                           const std::string& std_err) {
   SPDLOG_LOGGER_TRACE(_commands_logger, "raw_v2::_on_complete: {} id={}",
@@ -394,13 +398,13 @@ void raw_v2::_on_complete(const common::process<true>& proc,
   res.end_time = time(nullptr);
   res.exit_code = exit_code;
   res.output = !std_out.empty() ? std_out : std_err;
-  res.exit_status = exit_status;
+  res.exit_status = static_cast<process::status>(exit_status);
 
-  if (res.exit_status == common::e_exit_status::timeout) {
+  if (res.exit_status == process::timeout) {
     res.exit_code = service::state_unknown;
     res.output = "(Process Timeout)";
-  } else if ((res.exit_status == common::e_exit_status::crash) ||
-             (res.exit_code < -1) || (res.exit_code > 3))
+  } else if ((res.exit_status == process::crash) || (res.exit_code < -1) ||
+             (res.exit_code > 3))
     res.exit_code = service::state_unknown;
 
   SPDLOG_LOGGER_TRACE(_commands_logger, "raw::finished: name:{} id={}, {}",
@@ -459,14 +463,14 @@ void raw_v2::run(const std::string& processed_cmd,
     new_process->start_process(
         [me = shared_from_this(), command_id, start = time(nullptr), &waiter,
          &done, &res](const common::process<true>&, int exit_code,
-                      common::e_exit_status exit_status,
-                      const std::string& std_out, const std::string& std_err) {
+                      int exit_status, const std::string& std_out,
+                      const std::string& std_err) {
           absl::MutexLock lck(&waiter);
           res.command_id = command_id;
           res.start_time = start;
           res.end_time = time(nullptr);
           res.exit_code = exit_code;
-          res.exit_status = exit_status;
+          res.exit_status = static_cast<process::status>(exit_status);
           res.output = !std_out.empty() ? std_out : std_err;
           done = true;
         },
@@ -484,11 +488,11 @@ void raw_v2::run(const std::string& processed_cmd,
   absl::MutexLock lck(&waiter);
   waiter.Await(absl::Condition(&done));
 
-  if (res.exit_status == common::e_exit_status::timeout) {
+  if (res.exit_status == process::timeout) {
     res.exit_code = service::state_unknown;
     res.output = "(Process Timeout)";
-  } else if (res.exit_status == common::e_exit_status::crash ||
-             res.exit_code < -1 || res.exit_code > 3)
+  } else if (res.exit_status == process::crash || res.exit_code < -1 ||
+             res.exit_code > 3)
     res.exit_code = service::state_unknown;
 
   SPDLOG_LOGGER_TRACE(_commands_logger,
