@@ -26,11 +26,14 @@
 #include "com/centreon/engine/command_manager.hh"
 #include "com/centreon/engine/configuration/applier/state.hh"
 #include "com/centreon/engine/configuration/extended_conf.hh"
-#include "com/centreon/engine/configuration/parser.hh"
 #include "com/centreon/engine/globals.hh"
 #include "com/centreon/engine/logging/logger.hh"
 #include "com/centreon/engine/statusdata.hh"
-#include "com/centreon/logging/engine.hh"
+#ifdef LEGACY_CONF
+#include "common/engine_legacy_conf/parser.hh"
+#else
+#include "common/engine_conf/parser.hh"
+#endif
 
 using namespace com::centreon::engine;
 using namespace com::centreon::engine::events;
@@ -89,7 +92,9 @@ void loop::run() {
  */
 loop::loop() : _need_reload(0), _reload_running(false) {}
 
+#ifdef LEGACY_CONF
 static void apply_conf(std::atomic<bool>* reloading) {
+  configuration::error_cnt err;
   engine_logger(log_info_message, more) << "Starting to reload configuration.";
   process_logger->info("Starting to reload configuration.");
   try {
@@ -97,10 +102,10 @@ static void apply_conf(std::atomic<bool>* reloading) {
     {
       configuration::parser p;
       std::string path(::config->cfg_main());
-      p.parse(path, config);
+      p.parse(path, config, err);
     }
     configuration::extended_conf::update_state(config);
-    configuration::applier::state::instance().apply(config);
+    configuration::applier::state::instance().apply(config, err);
     engine_logger(log_info_message, basic)
         << "Configuration reloaded, main loop continuing.";
     process_logger->info("Configuration reloaded, main loop continuing.");
@@ -112,6 +117,28 @@ static void apply_conf(std::atomic<bool>* reloading) {
   engine_logger(log_info_message, more) << "Reload configuration finished.";
   process_logger->info("Reload configuration finished.");
 }
+#else
+static void apply_conf(std::atomic<bool>* reloading) {
+  configuration::error_cnt err;
+  process_logger->info("Starting to reload configuration.");
+  try {
+    configuration::State config;
+    configuration::state_helper config_hlp(&config);
+    {
+      configuration::parser p;
+      std::string path(::pb_config.cfg_main());
+      p.parse(path, &config, err);
+    }
+    configuration::extended_conf::update_state(&config);
+    configuration::applier::state::instance().apply(config, err);
+    process_logger->info("Configuration reloaded, main loop continuing.");
+  } catch (std::exception const& e) {
+    config_logger->error("Error: {}", e.what());
+  }
+  *reloading = false;
+  process_logger->info("Reload configuration finished.");
+}
+#endif
 
 /**
  *  Slot to dispatch Centreon Engine events.
@@ -161,6 +188,26 @@ void loop::_dispatching() {
 
     configuration::applier::state::instance().lock();
 
+#ifdef LEGACY_CONF
+    time_t time_change_threshold = config->time_change_threshold();
+    uint32_t max_parallel_service_checks =
+        config->max_parallel_service_checks();
+    bool execute_service_checks = config->execute_service_checks();
+    bool execute_host_checks = config->execute_host_checks();
+    uint32_t interval_length = config->interval_length();
+    double sleep_time = config->sleep_time();
+    int32_t command_check_interval = config->command_check_interval();
+#else
+    time_t time_change_threshold = pb_config.time_change_threshold();
+    uint32_t max_parallel_service_checks =
+        pb_config.max_parallel_service_checks();
+    bool execute_service_checks = pb_config.execute_service_checks();
+    bool execute_host_checks = pb_config.execute_host_checks();
+    uint32_t interval_length = pb_config.interval_length();
+    double sleep_time = pb_config.sleep_time();
+    int32_t command_check_interval = pb_config.command_check_interval();
+#endif
+
     // Hey, wait a second...  we traveled back in time!
     if (current_time < _last_time)
       compensate_for_system_time_change(
@@ -169,7 +216,7 @@ void loop::_dispatching() {
     // Else if the time advanced over the specified threshold,
     // try and compensate...
     else if ((current_time - _last_time) >=
-             static_cast<time_t>(config->time_change_threshold()))
+             static_cast<time_t>(time_change_threshold))
       compensate_for_system_time_change(
           static_cast<unsigned long>(_last_time),
           static_cast<unsigned long>(current_time));
@@ -204,10 +251,10 @@ void loop::_dispatching() {
     }
     engine_logger(dbg_events, more)
         << "Current/Max Service Checks: " << currently_running_service_checks
-        << '/' << config->max_parallel_service_checks();
+        << '/' << max_parallel_service_checks;
     events_logger->debug("Current/Max Service Checks: {}/{}",
                          currently_running_service_checks,
-                         config->max_parallel_service_checks());
+                         max_parallel_service_checks);
 
     // Update status information occassionally - NagVis watches the
     // NDOUtils DB to see if Engine is alive.
@@ -248,46 +295,43 @@ void loop::_dispatching() {
 
         // Don't run a service check if we're already maxed out on the
         // number of parallel service checks...
-        if (config->max_parallel_service_checks() != 0 &&
-            currently_running_service_checks >=
-                config->max_parallel_service_checks()) {
+        if (max_parallel_service_checks != 0 &&
+            currently_running_service_checks >= max_parallel_service_checks) {
           // Move it at least 5 seconds (to overcome the current peak),
           // with a random 10 seconds (to spread the load).
           nudge_seconds = 5 + (rand() % 10);
           engine_logger(dbg_events | dbg_checks, basic)
               << "**WARNING** Max concurrent service checks ("
               << currently_running_service_checks << "/"
-              << config->max_parallel_service_checks()
-              << ") has been reached!  Nudging " << temp_service->get_hostname()
-              << ":" << temp_service->description() << " by " << nudge_seconds
+              << max_parallel_service_checks << ") has been reached!  Nudging "
+              << temp_service->get_hostname() << ":"
+              << temp_service->description() << " by " << nudge_seconds
               << " seconds...";
           events_logger->trace(
               "**WARNING** Max concurrent service checks ({}/{}) has been "
               "reached!  Nudging {}:{} by {} seconds...",
-              currently_running_service_checks,
-              config->max_parallel_service_checks(),
+              currently_running_service_checks, max_parallel_service_checks,
               temp_service->get_hostname(), temp_service->description(),
               nudge_seconds);
 
           engine_logger(log_runtime_warning, basic)
               << "\tMax concurrent service checks ("
               << currently_running_service_checks << "/"
-              << config->max_parallel_service_checks()
-              << ") has been reached.  Nudging " << temp_service->get_hostname()
-              << ":" << temp_service->description() << " by " << nudge_seconds
+              << max_parallel_service_checks << ") has been reached.  Nudging "
+              << temp_service->get_hostname() << ":"
+              << temp_service->description() << " by " << nudge_seconds
               << " seconds...";
           runtime_logger->warn(
               "\tMax concurrent service checks ({}/{}) has been reached.  "
               "Nudging {}:{} by {} seconds...",
-              currently_running_service_checks,
-              config->max_parallel_service_checks(),
+              currently_running_service_checks, max_parallel_service_checks,
               temp_service->get_hostname(), temp_service->description(),
               nudge_seconds);
           run_event = false;
         }
 
         // Don't run a service check if active checks are disabled.
-        if (!config->execute_service_checks()) {
+        if (!execute_service_checks) {
           engine_logger(dbg_events | dbg_checks, more)
               << "We're not executing service checks right now, "
               << "so we'll skip this event.";
@@ -322,16 +366,15 @@ void loop::_dispatching() {
                 temp_service->get_current_state() != service::state_ok)
               temp_service->set_next_check(
                   (time_t)(temp_service->get_next_check() +
-                           temp_service->retry_interval() *
-                               config->interval_length()));
+                           temp_service->retry_interval() * interval_length));
             else
               temp_service->set_next_check(
                   (time_t)(temp_service->get_next_check() +
-                           (temp_service->check_interval() * interval_length)));
+                           temp_service->check_interval() * interval_length));
           }
           temp_event->run_time = temp_service->get_next_check();
           reschedule_event(std::move(temp_event), events::loop::low);
-          temp_service->update_status(notifier::status_attribute::NEXT_CHECK);
+          temp_service->update_status();
           run_event = false;
         }
       }
@@ -344,7 +387,7 @@ void loop::_dispatching() {
             static_cast<host*>(_event_list_low.front()->event_data));
 
         // Don't run a host check if active checks are disabled.
-        if (!config->execute_host_checks()) {
+        if (!execute_host_checks) {
           engine_logger(dbg_events | dbg_checks, more)
               << "We're not executing host checks right now, "
               << "so we'll skip this event.";
@@ -370,16 +413,16 @@ void loop::_dispatching() {
           // Reschedule.
           if ((notifier::soft == temp_host->get_state_type()) &&
               (temp_host->get_current_state() != host::state_up))
-            temp_host->set_next_check((time_t)(temp_host->get_next_check() +
-                                               temp_host->retry_interval() *
-                                                   config->interval_length()));
+            temp_host->set_next_check(
+                (time_t)(temp_host->get_next_check() +
+                         temp_host->retry_interval() * interval_length));
           else
-            temp_host->set_next_check((time_t)(temp_host->get_next_check() +
-                                               temp_host->check_interval() *
-                                                   config->interval_length()));
+            temp_host->set_next_check(
+                (time_t)(temp_host->get_next_check() +
+                         temp_host->check_interval() * interval_length));
           temp_event->run_time = temp_host->get_next_check();
           reschedule_event(std::move(temp_event), events::loop::low);
-          temp_host->update_status(notifier::status_attribute::NEXT_CHECK);
+          temp_host->update_status();
           run_event = false;
         }
       }
@@ -406,7 +449,7 @@ void loop::_dispatching() {
             << "Did not execute scheduled event. Idling for a bit...";
         events_logger->debug(
             "Did not execute scheduled event. Idling for a bit...");
-        uint64_t d = static_cast<uint64_t>(config->sleep_time() * 1000000000);
+        uint64_t d = static_cast<uint64_t>(sleep_time * 1000000000);
         std::this_thread::sleep_for(std::chrono::nanoseconds(d));
       }
     }
@@ -422,7 +465,7 @@ void loop::_dispatching() {
 
       // Check for external commands if we're supposed to check as
       // often as possible.
-      if (config->command_check_interval() == -1) {
+      if (command_check_interval == -1) {
         // Send data to event broker.
         broker_external_command(NEBTYPE_EXTERNALCOMMAND_CHECK, CMD_NONE,
                                 nullptr, nullptr);
@@ -430,19 +473,18 @@ void loop::_dispatching() {
 
       auto t1 = std::chrono::system_clock::now();
       auto delay = std::chrono::nanoseconds(
-          static_cast<uint64_t>(1000000000 * config->sleep_time()));
+          static_cast<uint64_t>(1000000000 * sleep_time));
       command_manager::instance().execute();
 
       // Set time to sleep so we don't hog the CPU...
-      timespec sleep_time;
-      sleep_time.tv_sec = (time_t)config->sleep_time();
-      sleep_time.tv_nsec =
-          (long)((config->sleep_time() - (double)sleep_time.tv_sec) *
-                 1000000000ull);
+      timespec stime;
+      stime.tv_sec = (time_t)sleep_time;
+      stime.tv_nsec =
+          (long)((sleep_time - (double)stime.tv_sec) * 1000000000ull);
 
       // Populate fake "sleep" event.
       _sleep_event.run_time = current_time;
-      _sleep_event.event_data = (void*)&sleep_time;
+      _sleep_event.event_data = (void*)&stime;
 
       // Send event data to broker.
       broker_timed_event(NEBTYPE_TIMEDEVENT_SLEEP, NEBFLAG_NONE, NEBATTR_NONE,
