@@ -31,6 +31,7 @@
 
 using namespace com::centreon::engine::retention;
 
+#ifdef LEGACY_CONF
 /**
  *  Restore retention state.
  *
@@ -83,3 +84,57 @@ void applier::state::apply(configuration::state& config,
   broker_retention_data(NEBTYPE_RETENTIONDATA_ENDLOAD, NEBFLAG_NONE,
                         NEBATTR_NONE, NULL);
 }
+#else
+/**
+ *  Restore retention state.
+ *
+ *  @param[in, out] config The global configuration to update.
+ *  @param[in]      state  The retention informations.
+ */
+void applier::state::apply(configuration::State& config,
+                           const retention::state& state) {
+  if (!config.retain_state_information())
+    return;
+
+  // send data to event broker.
+  broker_retention_data(NEBTYPE_RETENTIONDATA_STARTLOAD, NEBFLAG_NONE,
+                        NEBATTR_NONE, NULL);
+
+  try {
+    time_t current_time(time(NULL));
+    bool scheduling_info_is_ok(false);
+    if ((current_time - state.informations().created()) <
+        static_cast<time_t>(config.retention_scheduling_horizon()))
+      scheduling_info_is_ok = true;
+
+    applier::program app_program;
+    app_program.apply(config, state.globals());
+
+    applier::comment app_comments;
+    app_comments.apply(state.comments());
+
+    applier::downtime::apply(state.downtimes());
+
+    applier::contact app_contacts;
+    app_contacts.apply(config, state.contacts());
+
+    applier::host app_hosts;
+    app_hosts.apply(config, state.hosts(), scheduling_info_is_ok);
+
+    applier::service::apply(config, state.services(), scheduling_info_is_ok);
+
+    applier::anomalydetection::apply(config, state.anomalydetection(),
+                                     scheduling_info_is_ok);
+
+  } catch (...) {
+    // send data to event broker.
+    broker_retention_data(NEBTYPE_RETENTIONDATA_ENDLOAD, NEBFLAG_NONE,
+                          NEBATTR_NONE, NULL);
+    throw;
+  }
+
+  // send data to event broker.
+  broker_retention_data(NEBTYPE_RETENTIONDATA_ENDLOAD, NEBFLAG_NONE,
+                        NEBATTR_NONE, NULL);
+}
+#endif
