@@ -25,10 +25,17 @@
 #include "../timeperiod/utils.hh"
 #include "com/centreon/engine/configuration/applier/contact.hh"
 #include "com/centreon/engine/configuration/applier/host.hh"
-#include "com/centreon/engine/configuration/host.hh"
 #include "com/centreon/engine/exceptions/error.hh"
+#include "com/centreon/engine/host.hh"
 #include "com/centreon/engine/hostescalation.hh"
 #include "com/centreon/engine/timezone_manager.hh"
+#ifdef LEGACY_CONF
+#include "common/engine_legacy_conf/host.hh"
+#include "common/engine_legacy_conf/state.hh"
+#else
+#include "common/engine_conf/contact_helper.hh"
+#include "common/engine_conf/host_helper.hh"
+#endif
 #include "helper.hh"
 
 using namespace com::centreon;
@@ -39,22 +46,38 @@ using namespace com::centreon::engine::configuration::applier;
 class HostFlappingNotification : public TestEngine {
  public:
   void SetUp() override {
+    configuration::error_cnt err;
     init_config_state();
 
     configuration::applier::contact ct_aply;
+#ifdef LEGACY_CONF
     configuration::contact ctct{new_configuration_contact("admin", true)};
     ct_aply.add_object(ctct);
     ct_aply.expand_objects(*config);
-    ct_aply.resolve_object(ctct);
+#else
+    configuration::Contact ctct{new_pb_configuration_contact("admin", true)};
+    ct_aply.add_object(ctct);
+    ct_aply.expand_objects(pb_config);
+#endif
+    ct_aply.resolve_object(ctct, err);
 
     configuration::applier::host hst_aply;
+#ifdef LEGACY_CONF
     configuration::host hst;
     hst.parse("host_name", "test_host");
     hst.parse("address", "127.0.0.1");
     hst.parse("_HOST_ID", "12");
     hst.parse("contacts", "admin");
+#else
+    configuration::Host hst;
+    configuration::host_helper hst_hlp(&hst);
+    hst.set_host_name("test_host");
+    hst.set_address("127.0.0.1");
+    hst.set_host_id(12);
+    hst_hlp.hook("contacts", "admin");
+#endif
     hst_aply.add_object(hst);
-    hst_aply.resolve_object(hst);
+    hst_aply.resolve_object(hst, err);
     host_map const& hm{engine::host::hosts};
     _host = hm.begin()->second;
     _host->set_current_state(engine::host::state_up);
@@ -62,14 +85,24 @@ class HostFlappingNotification : public TestEngine {
     _host->set_acknowledgement(AckType::NONE);
     _host->set_notify_on(static_cast<uint32_t>(-1));
 
+#ifdef LEGACY_CONF
     configuration::host hst_child;
     hst_child.parse("host_name", "child_host");
     hst_child.parse("parents", "test_host");
     hst_child.parse("address", "127.0.0.1");
     hst_child.parse("_HOST_ID", "13");
     hst_child.parse("contacts", "admin");
+#else
+    configuration::Host hst_child;
+    configuration::host_helper hst_child_hlp(&hst_child);
+    hst_child.set_host_name("child_host");
+    hst_child.set_address("127.0.0.1");
+    hst_child_hlp.hook("parents", "test_host");
+    hst_child.set_host_id(13);
+    hst_child_hlp.hook("contacts", "admin");
+#endif
     hst_aply.add_object(hst_child);
-    hst_aply.resolve_object(hst_child);
+    hst_aply.resolve_object(hst_child, err);
 
     _host2 = hm.begin()->second;
     _host2->set_current_state(engine::host::state_up);
@@ -101,15 +134,13 @@ TEST_F(HostFlappingNotification, SimpleHostFlapping) {
    * If we call time(), it is not the glibc time() function that will be called.
    */
   set_time(43000);
-  // FIXME DBR: should not we find a better solution than fixing this each time?
   _host->set_last_hard_state_change(43000);
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
-  for (size_t i = 0; i < tperiod->days.size(); ++i)
-    tperiod->days[i].emplace_back(0, 86400);
+      new_timeperiod_with_timeranges("tperiod", "alias")};
 
-  std::unique_ptr<engine::hostescalation> host_escalation{
-      new engine::hostescalation("host_name", 0, 1, 1.0, "tperiod", 7, Uuid())};
+  std::unique_ptr<engine::hostescalation> host_escalation =
+      std::make_unique<engine::hostescalation>("host_name", 0, 1, 1.0,
+                                               "tperiod", 7, 12345);
 
   ASSERT_TRUE(host_escalation);
   uint64_t id{_host->get_next_notification_id()};
@@ -153,13 +184,36 @@ TEST_F(HostFlappingNotification, SimpleHostFlappingStartTwoTimes) {
    */
   set_time(43000);
   _host->set_notification_interval(2);
+#ifdef LEGACY_CONF
   std::unique_ptr<engine::timeperiod> tperiod{
       new engine::timeperiod("tperiod", "alias")};
   for (uint32_t i = 0; i < tperiod->days.size(); ++i)
     tperiod->days[i].emplace_back(0, 86400);
+#else
+  configuration::Timeperiod tp;
+  configuration::timeperiod_helper tp_hlp(&tp);
+  tp.set_timeperiod_name("tperiod");
+  tp.set_alias("alias");
+#define add_day(day)                                \
+  {                                                 \
+    auto* d = tp.mutable_timeranges()->add_##day(); \
+    d->set_range_start(0);                          \
+    d->set_range_end(86400);                        \
+  }
+
+  add_day(sunday);
+  add_day(monday);
+  add_day(tuesday);
+  add_day(wednesday);
+  add_day(thursday);
+  add_day(friday);
+  add_day(saturday);
+
+  std::unique_ptr<engine::timeperiod> tperiod{new engine::timeperiod(tp)};
+#endif
 
   std::unique_ptr<engine::hostescalation> host_escalation{
-      new engine::hostescalation("host_name", 0, 1, 1.0, "tperiod", 7, Uuid())};
+      new engine::hostescalation("host_name", 0, 1, 1.0, "tperiod", 7, 12345)};
 
   ASSERT_TRUE(host_escalation);
   uint64_t id{_host->get_next_notification_id()};
@@ -192,13 +246,36 @@ TEST_F(HostFlappingNotification, SimpleHostFlappingStopTwoTimes) {
    */
   set_time(43000);
   _host->set_notification_interval(2);
+#ifdef LEGACY_CONF
   std::unique_ptr<engine::timeperiod> tperiod{
       new engine::timeperiod("tperiod", "alias")};
   for (uint32_t i = 0; i < tperiod->days.size(); ++i)
     tperiod->days[i].emplace_back(0, 86400);
+#else
+  configuration::Timeperiod tp;
+  configuration::timeperiod_helper tp_hlp(&tp);
+  tp.set_timeperiod_name("tperiod");
+  tp.set_alias("alias");
+#define add_day(day)                                \
+  {                                                 \
+    auto* d = tp.mutable_timeranges()->add_##day(); \
+    d->set_range_start(0);                          \
+    d->set_range_end(86400);                        \
+  }
+
+  add_day(sunday);
+  add_day(monday);
+  add_day(tuesday);
+  add_day(wednesday);
+  add_day(thursday);
+  add_day(friday);
+  add_day(saturday);
+
+  std::unique_ptr<engine::timeperiod> tperiod{new engine::timeperiod(tp)};
+#endif
 
   std::unique_ptr<engine::hostescalation> host_escalation{
-      new engine::hostescalation("host_name", 0, 1, 1.0, "tperiod", 7, Uuid())};
+      new engine::hostescalation("host_name", 0, 1, 1.0, "tperiod", 7, 12345)};
 
   ASSERT_TRUE(host_escalation);
   uint64_t id{_host->get_next_notification_id()};
@@ -225,7 +302,11 @@ TEST_F(HostFlappingNotification, SimpleHostFlappingStopTwoTimes) {
 }
 
 TEST_F(HostFlappingNotification, CheckFlapping) {
+#ifdef LEGACY_CONF
   config->enable_flap_detection(true);
+#else
+  pb_config.set_enable_flap_detection(true);
+#endif
   _host->set_flap_detection_enabled(true);
   _host->add_flap_detection_on(engine::host::up);
   _host->add_flap_detection_on(engine::host::down);
@@ -286,7 +367,11 @@ TEST_F(HostFlappingNotification, CheckFlapping) {
 }
 
 TEST_F(HostFlappingNotification, CheckFlappingWithHostParentDown) {
+#ifdef LEGACY_CONF
   config->enable_flap_detection(true);
+#else
+  pb_config.set_enable_flap_detection(true);
+#endif
   _host->set_current_state(engine::host::state_down);
   _host->set_last_hard_state(engine::host::state_down);
   _host->set_state_type(checkable::hard);
