@@ -25,12 +25,15 @@
 #include "com/centreon/engine/configuration/applier/contact.hh"
 #include "com/centreon/engine/configuration/applier/host.hh"
 #include "com/centreon/engine/configuration/applier/service.hh"
-#include "com/centreon/engine/configuration/host.hh"
-#include "com/centreon/engine/configuration/service.hh"
+#include "com/centreon/engine/globals.hh"
 #include "com/centreon/engine/retention/dump.hh"
 #include "com/centreon/engine/serviceescalation.hh"
 #include "com/centreon/engine/timezone_manager.hh"
 #include "com/centreon/process_manager.hh"
+#ifdef LEGACY_CONF
+#include "common/engine_legacy_conf/host.hh"
+#include "common/engine_legacy_conf/service.hh"
+#endif
 #include "helper.hh"
 
 using namespace com::centreon;
@@ -42,20 +45,37 @@ using namespace com::centreon::engine::retention;
 class ServiceFlappingNotification : public TestEngine {
  public:
   void SetUp() override {
+    error_cnt err;
     init_config_state();
 
     configuration::applier::contact ct_aply;
+#ifdef LEGACY_CONF
     configuration::contact ctct{new_configuration_contact("admin", true)};
+#else
+    configuration::Contact ctct{new_pb_configuration_contact("admin", true)};
+#endif
     ct_aply.add_object(ctct);
+#ifdef LEGACY_CONF
     ct_aply.expand_objects(*config);
-    ct_aply.resolve_object(ctct);
+#else
+    ct_aply.expand_objects(pb_config);
+#endif
+    ct_aply.resolve_object(ctct, err);
 
     configuration::applier::command cmd_aply;
+#ifdef LEGACY_CONF
     configuration::command cmd("cmd");
     cmd.parse("command_line", "echo 1");
+#else
+    configuration::Command cmd;
+    configuration::command_helper cmd_hlp(&cmd);
+    cmd.set_command_name("cmd");
+    cmd.set_command_line("echo 1");
+#endif
     cmd_aply.add_object(cmd);
 
     configuration::applier::host hst_aply;
+#ifdef LEGACY_CONF
     configuration::host hst;
     hst.parse("host_name", "test_host");
     hst.parse("address", "127.0.0.1");
@@ -63,22 +83,42 @@ class ServiceFlappingNotification : public TestEngine {
     hst.parse("check_command", "cmd");
     hst.parse("active_checks_enabled", "0");
     hst.parse("passive_checks_enabled", "1");
+#else
+    configuration::Host hst;
+    configuration::host_helper hst_hlp(&hst);
+    hst.set_host_name("test_host");
+    hst.set_address("127.0.0.1");
+    hst.set_host_id(12);
+    hst.set_check_command("cmd");
+    hst.set_checks_active(false);
+    hst.set_checks_passive(true);
+#endif
     hst_aply.add_object(hst);
-    hst_aply.resolve_object(hst);
+    hst_aply.resolve_object(hst, err);
 
     configuration::applier::service svc_aply;
+#ifdef LEGACY_CONF
     configuration::service svc;
     svc.parse("host", "test_host");
     svc.parse("service_description", "test_description");
     svc.parse("_SERVICE_ID", "12");
     svc.parse("check_command", "cmd");
     svc.parse("contacts", "admin");
+#else
+    configuration::Service svc;
+    configuration::service_helper svc_hlp(&svc);
+    svc.set_host_name("test_host");
+    svc.set_service_description("test_description");
+    svc.set_service_id(12);
+    svc.set_check_command("cmd");
+    svc_hlp.hook("contacts", "admin");
+#endif
 
     // We fake here the expand_object on configuration::service
     svc.set_host_id(12);
 
     svc_aply.add_object(svc);
-    svc_aply.resolve_object(svc);
+    svc_aply.resolve_object(svc, err);
 
     service_map const& sv{engine::service::services};
 
@@ -124,13 +164,11 @@ TEST_F(ServiceFlappingNotification, SimpleServiceFlapping) {
   // FIXME DBR: should not we find a better solution than fixing this each time?
   _service->set_last_hard_state_change(43000);
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
-  for (size_t i = 0; i < tperiod->days.size(); ++i)
-    tperiod->days[i].emplace_back(0, 86400);
+      new_timeperiod_with_timeranges("tperiod", "alias")};
 
   std::unique_ptr<engine::serviceescalation> service_escalation{
       new engine::serviceescalation("host_name", "test_description", 0, 1, 1.0,
-                                    "tperiod", 7, Uuid())};
+                                    "tperiod", 7, 12345)};
 
   ASSERT_TRUE(service_escalation);
   uint64_t id{_service->get_next_notification_id()};
@@ -177,13 +215,11 @@ TEST_F(ServiceFlappingNotification, SimpleServiceFlappingStartTwoTimes) {
   set_time(43000);
   _service->set_notification_interval(2);
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
-  for (uint32_t i = 0; i < tperiod->days.size(); ++i)
-    tperiod->days[i].emplace_back(0, 86400);
+      new_timeperiod_with_timeranges("tperiod", "alias")};
 
   std::unique_ptr<engine::serviceescalation> service_escalation{
       new engine::serviceescalation("host_name", "test_description", 0, 1, 1.0,
-                                    "tperiod", 7, Uuid())};
+                                    "tperiod", 7, 12345)};
 
   ASSERT_TRUE(service_escalation);
   uint64_t id{_service->get_next_notification_id()};
@@ -217,13 +253,11 @@ TEST_F(ServiceFlappingNotification, SimpleServiceFlappingStopTwoTimes) {
   set_time(43000);
   _service->set_notification_interval(2);
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
-  for (uint32_t i = 0; i < tperiod->days.size(); ++i)
-    tperiod->days[i].emplace_back(0, 86400);
+      new_timeperiod_with_timeranges("tperiod", "alias")};
 
   std::unique_ptr<engine::serviceescalation> service_escalation{
       new engine::serviceescalation("host_name", "test_description", 0, 1, 1.0,
-                                    "tperiod", 7, Uuid())};
+                                    "tperiod", 7, 12345)};
 
   ASSERT_TRUE(service_escalation);
   uint64_t id{_service->get_next_notification_id()};
@@ -250,7 +284,11 @@ TEST_F(ServiceFlappingNotification, SimpleServiceFlappingStopTwoTimes) {
 }
 
 TEST_F(ServiceFlappingNotification, CheckFlapping) {
+#ifdef LEGACY_CONF
   config->enable_flap_detection(true);
+#else
+  pb_config.set_enable_flap_detection(true);
+#endif
   _service->set_flap_detection_enabled(true);
   _service->add_flap_detection_on(engine::service::ok);
   _service->add_flap_detection_on(engine::service::down);
@@ -342,7 +380,11 @@ TEST_F(ServiceFlappingNotification, CheckFlapping) {
 }
 
 TEST_F(ServiceFlappingNotification, CheckFlappingWithVolatile) {
+#ifdef LEGACY_CONF
   config->enable_flap_detection(true);
+#else
+  pb_config.set_enable_flap_detection(true);
+#endif
   _service->set_flap_detection_enabled(true);
   _service->set_is_volatile(true);
   _service->add_flap_detection_on(engine::service::ok);
@@ -450,7 +492,11 @@ TEST_F(ServiceFlappingNotification, CheckFlappingWithHostDown) {
   _host->set_current_state(engine::host::state_down);
   _host->set_state_type(checkable::hard);
   _host->set_check_type(checkable::check_type::check_passive);
+#ifdef LEGACY_CONF
   config->enable_flap_detection(true);
+#else
+  pb_config.set_enable_flap_detection(true);
+#endif
   _service->set_flap_detection_enabled(true);
   _service->add_flap_detection_on(engine::service::ok);
   _service->add_flap_detection_on(engine::service::down);
@@ -464,6 +510,8 @@ TEST_F(ServiceFlappingNotification, CheckFlappingWithHostDown) {
   _service->set_first_notification_delay(3);
   _service->set_max_attempts(1);
 
+  commands_logger->set_level(spdlog::level::trace);
+
   // This loop is to store many OK in the state history.
   for (int i = 1; i < 22; i++) {
     now += 300;
@@ -539,7 +587,11 @@ TEST_F(ServiceFlappingNotification, CheckFlappingWithHostDown) {
 }
 
 TEST_F(ServiceFlappingNotification, CheckFlappingWithSoftState) {
+#ifdef LEGACY_CONF
   config->enable_flap_detection(true);
+#else
+  pb_config.set_enable_flap_detection(true);
+#endif
   _service->set_flap_detection_enabled(true);
   _service->add_flap_detection_on(engine::service::ok);
   _service->add_flap_detection_on(engine::service::down);
@@ -628,7 +680,11 @@ TEST_F(ServiceFlappingNotification, CheckFlappingWithSoftState) {
 }
 
 TEST_F(ServiceFlappingNotification, RetentionFlappingNotification) {
+#ifdef LEGACY_CONF
   config->enable_flap_detection(true);
+#else
+  pb_config.set_enable_flap_detection(true);
+#endif
   _service->set_flap_detection_enabled(true);
   _service->add_flap_detection_on(engine::service::ok);
   _service->add_flap_detection_on(engine::service::down);
