@@ -1,33 +1,34 @@
 /**
-* Copyright 2016 Centreon
-*
-* This file is part of Centreon Engine.
-*
-* Centreon Engine is free software: you can redistribute it and/or
-* modify it under the terms of the GNU General Public License version 2
-* as published by the Free Software Foundation.
-*
-* Centreon Engine is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-* General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with Centreon Engine. If not, see
-* <http://www.gnu.org/licenses/>.
-*/
+ * Copyright 2016 Centreon
+ *
+ * This file is part of Centreon Engine.
+ *
+ * Centreon Engine is free software: you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License version 2
+ * as published by the Free Software Foundation.
+ *
+ * Centreon Engine is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with Centreon Engine. If not, see
+ * <http://www.gnu.org/licenses/>.
+ */
 
 #include <gtest/gtest.h>
 #include <cstring>
 #include "com/centreon/clib.hh"
 #include "com/centreon/engine/configuration/applier/state.hh"
 #include "com/centreon/engine/timeperiod.hh"
+#include "test_engine.hh"
 #include "tests/timeperiod/utils.hh"
 
 using namespace com::centreon;
 using namespace com::centreon::engine;
 
-class GetNextValidTimeCalendarDateTest : public ::testing::Test {
+class GetNextValidTimeCalendarDateTest : public TestEngine {
  public:
   void default_data_set() {
     _creator.new_timeperiod();
@@ -90,7 +91,7 @@ TEST_F(GetNextValidTimeCalendarDateTest, WithinCalendarDate) {
 // Then the next valid time is now
 TEST_F(GetNextValidTimeCalendarDateTest, AfterCalendarDates) {
   std::unique_ptr<engine::timeperiod> tiperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
 
   for (int i = 0; i < 7; ++i) {
     timerange_list list_time;
