@@ -1,6 +1,6 @@
 #!/usr/bin/python3
 #
-# Copyright 2023-2024 Centreon
+# Copyright 2023-2025 Centreon
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,6 +19,8 @@
 # This script is a little tcp server working on port 5669. It can simulate
 # a cbd instance. It is useful to test the validity of BBDO packets sent by
 # centengine.
+
+import jwt
 from robot.api import logger
 from subprocess import getoutput, Popen, DEVNULL
 import re
@@ -28,28 +30,65 @@ from google.protobuf.json_format import MessageToJson
 import time
 import json
 import psutil
+import shutil
 import random
 import string
 from dateutil import parser
-from datetime import datetime
+from datetime import datetime, timedelta
 import pymysql.cursors
-from robot.libraries.BuiltIn import BuiltIn
+from robot.libraries.BuiltIn import BuiltIn, RobotNotRunningError
 from concurrent import futures
 import grpc
 import grpc_stream_pb2_grpc
 
 
+def import_robot_resources():
+    global DB_NAME_STORAGE, VAR_ROOT, ETC_ROOT, DB_NAME_CONF, DB_USER, DB_PASS, DB_HOST, DB_PORT
+    try:
+        BuiltIn().import_resource('db_variables.resource')
+        DB_NAME_STORAGE = BuiltIn().get_variable_value("${DBName}")
+        DB_NAME_CONF = BuiltIn().get_variable_value("${DBNameConf}")
+        DB_USER = BuiltIn().get_variable_value("${DBUser}")
+        DB_PASS = BuiltIn().get_variable_value("${DBPass}")
+        DB_HOST = BuiltIn().get_variable_value("${DBHost}")
+        DB_PORT = BuiltIn().get_variable_value("${DBPort}")
+        VAR_ROOT = BuiltIn().get_variable_value("${VarRoot}")
+        ETC_ROOT = BuiltIn().get_variable_value("${EtcRoot}")
+    except RobotNotRunningError:
+        # Handle this case if Robot Framework is not running
+        print("Robot Framework is not running. Skipping resource import.")
+
+
+DB_NAME_STORAGE = ""
+DB_NAME_CONF = ""
+DB_USER = ""
+DB_PASS = ""
+DB_HOST = ""
+DB_PORT = ""
+VAR_ROOT = ""
+ETC_ROOT = ""
+
+BBDO2 = True
+
+import_robot_resources()
 TIMEOUT = 30
 
-BuiltIn().import_resource('db_variables.resource')
-DB_NAME_STORAGE = BuiltIn().get_variable_value("${DBName}")
-DB_NAME_CONF = BuiltIn().get_variable_value("${DBNameConf}")
-DB_USER = BuiltIn().get_variable_value("${DBUser}")
-DB_PASS = BuiltIn().get_variable_value("${DBPass}")
-DB_HOST = BuiltIn().get_variable_value("${DBHost}")
-DB_PORT = BuiltIn().get_variable_value("${DBPort}")
-VAR_ROOT = BuiltIn().get_variable_value("${VarRoot}")
-ETC_ROOT = BuiltIn().get_variable_value("${EtcRoot}")
+
+def ctn_in_bbdo2():
+    """ Check if we are in bbdo2 mode
+    """
+    global BBDO2
+    return BBDO2
+
+
+def ctn_set_bbdo2(value: bool):
+    """ Set the bbdo2 mode
+
+    Args:
+        value (bool): The value to set
+    """
+    global BBDO2
+    BBDO2 = value
 
 
 def ctn_parse_tests_params():
@@ -161,7 +200,7 @@ def ctn_wait_for_listen_on_range(port1: int, port2: int, prog: str, timeout: int
     return False
 
 
-def ctn_get_date(d: str):
+def ctn_get_date(d: str, agent_format: bool = False):
     """Generates a date from a string. This string can be just a timestamp or a date in iso format
 
     Args:
@@ -174,17 +213,20 @@ def ctn_get_date(d: str):
         ts = int(d)
         retval = datetime.fromtimestamp(int(ts))
     except ValueError:
-        retval = parser.parse(d[:-6])
+        if (not agent_format):
+            retval = parser.parse(d[:-6])
+        else:
+            retval = parser.parse(d)
     return retval
 
 
-def ctn_extract_date_from_log(line: str):
+def ctn_extract_date_from_log(line: str, agent_format: bool = False):
     p = re.compile(r"\[([^\]]*)\]")
     m = p.match(line)
     if m is None:
         return None
     try:
-        return ctn_get_date(m.group(1))
+        return ctn_get_date(m.group(1), agent_format)
     except parser.ParserError:
         logger.console(f"Unable to parse the date from the line {line}")
         return None
@@ -196,12 +238,13 @@ def ctn_get_round_current_date():
     return int(time.time())
 
 
-def ctn_find_regex_in_log_with_timeout(log: str, date, content, timeout: int):
+def ctn_find_regex_in_log_with_timeout(log: str, date, content, timeout: int, agent_format: bool = False):
 
     limit = time.time() + timeout
     c = ""
     while time.time() < limit:
-        ok, c = ctn_find_in_log(log, date, content, regex=True)
+        ok, c = ctn_find_in_log(
+            log, date, content, regex=True, agent_format=agent_format)
         if ok:
             return True, c
         time.sleep(5)
@@ -255,17 +298,20 @@ def ctn_find_in_log(log: str, date, content, **kwargs):
     """
     verbose = True
     regex = False
+    agent_format = False
     if 'verbose' in kwargs:
         verbose = 'verbose' == 'True'
     if 'regex' in kwargs:
         regex = bool(kwargs['regex'])
+    if 'agent_format' in kwargs:
+        agent_format = bool(kwargs['agent_format'])
 
     res = []
 
     try:
         with open(log, "r") as f:
             lines = f.readlines()
-        idx = ctn_find_line_from(lines, date)
+        idx = ctn_find_line_from(lines, date, agent_format)
 
         for c in content:
             found = False
@@ -301,14 +347,18 @@ def ctn_get_hostname():
     return retval
 
 
-def ctn_create_key_and_certificate(host: str, key: str, cert: str):
+def ctn_create_key_and_certificate(host: str, key: str, cert: str, with_san: bool = False):
     if len(key) > 0:
         os.makedirs(os.path.dirname(key), mode=0o777, exist_ok=True)
     if len(cert) > 0:
         os.makedirs(os.path.dirname(cert), mode=0o777, exist_ok=True)
     if len(key) > 0:
-        getoutput(
-            f"openssl req -new -newkey rsa:2048 -days 365 -nodes -x509 -keyout {key} -out {cert} -subj '/CN={host}'")
+        if with_san:
+            getoutput(
+                f"openssl req -new -newkey rsa:2048 -days 365 -nodes -x509 -keyout {key} -out {cert} -addext \"subjectAltName=DNS:{host},IP:127.0.0.1\"")
+        else:
+            getoutput(
+                f"openssl req -new -newkey rsa:2048 -days 365 -nodes -x509 -keyout {key} -out {cert} -subj '/CN={host}'")
     else:
         getoutput(
             f"openssl req -new -newkey rsa:2048 -days 365 -nodes -x509 -out {cert} -subj '/CN={host}'")
@@ -319,7 +369,21 @@ def ctn_create_certificate(host: str, cert: str):
 
 
 def ctn_run_env():
-    return getoutput("echo $RUN_ENV | awk '{print $1}'")
+    """
+    ctn_run_env
+
+    Get RUN_ENV env variable content
+    """
+    return os.environ.get('RUN_ENV', '')
+
+
+def ctn_get_workspace_win():
+    """
+    ctn_get_workspace_win
+
+    Get WINDOWS_PROJECT_PATH env variable content
+    """
+    return os.environ.get('WINDOWS_PROJECT_PATH', '')
 
 
 def ctn_start_mysql():
@@ -426,8 +490,10 @@ def ctn_clear_cache():
 
 
 def ctn_clear_logs():
-    getoutput(f"rm -rf {VAR_ROOT}/log/centreon-engine/config*")
-    getoutput(f"rm -rf {VAR_ROOT}/log/centreon-broker")
+    shutil.rmtree(f"{VAR_ROOT}/log/centreon-engine", ignore_errors=True)
+    shutil.rmtree(f"{VAR_ROOT}/log/centreon-broker", ignore_errors=True)
+    os.makedirs(f"{VAR_ROOT}/log/centreon-engine")
+    os.makedirs(f"{VAR_ROOT}/log/centreon-broker")
 
 
 def ctn_engine_log_table_duplicate(result: list):
@@ -479,7 +545,7 @@ def ctn_check_engine_logs_are_duplicated(log: str, date):
         return False
 
 
-def ctn_find_line_from(lines, date):
+def ctn_find_line_from(lines, date, agent_format: bool = False):
     try:
         my_date = parser.parse(date)
     except:
@@ -491,13 +557,13 @@ def ctn_find_line_from(lines, date):
     idx = start
     while end > start:
         idx = (start + end) // 2
-        idx_d = ctn_extract_date_from_log(lines[idx])
+        idx_d = ctn_extract_date_from_log(lines[idx], agent_format)
         while idx_d is None:
             logger.console("Unable to parse the date ({} <= {} <= {}): <<{}>>".format(
                 start, idx, end, lines[idx]))
             idx -= 1
             if idx >= 0:
-                idx_d = ctn_extract_date_from_log(lines[idx])
+                idx_d = ctn_extract_date_from_log(lines[idx], agent_format)
             else:
                 logger.console("We are at the first line and no date found")
                 return 0
@@ -555,8 +621,13 @@ def ctn_clear_commands_status():
 
 
 def ctn_set_command_status(cmd, status):
-    if os.path.exists("/tmp/states"):
-        f = open("/tmp/states")
+    if os.environ.get("RUN_ENV", "") == "WSL":
+        state_path = "states"
+    else:
+        state_path = "/tmp/states"
+
+    if os.path.exists(state_path):
+        f = open(state_path)
         lines = f.readlines()
     else:
         lines = []
@@ -572,9 +643,8 @@ def ctn_set_command_status(cmd, status):
 
     if not done:
         lines.append("{}=>{}\n".format(cmd, status))
-    f = open("/tmp/states", "w")
-    f.writelines(lines)
-    f.close()
+    with open(state_path, "w") as f:
+        f.writelines(lines)
 
 
 def ctn_truncate_resource_host_service():
@@ -615,7 +685,9 @@ def ctn_check_service_resource_status_with_timeout(hostname: str, service_desc:
                 if len(result) > 0 and result[0]['status'] is not None and int(result[0]['status']) == int(status):
                     logger.console(
                         f"status={result[0]['status']} and status_confirmed={result[0]['status_confirmed']}")
-                    if state_type == 'HARD' and int(result[0]['status_confirmed']) == 1:
+                    if state_type == 'ANY':
+                        return True
+                    elif state_type == 'HARD' and int(result[0]['status_confirmed']) == 1:
                         return True
                     elif state_type == 'SOFT' and int(result[0]['status_confirmed']) == 0:
                         return True
@@ -623,6 +695,60 @@ def ctn_check_service_resource_status_with_timeout(hostname: str, service_desc:
     return False
 
 
+def ctn_check_service_resource_status_with_timeout_rt(hostname: str, service_desc: str, status: int, timeout: int, state_type: str = "SOFT"):
+    """
+    brief : same as ctn_check_service_resource_status_with_timeout but with additional return
+
+    Check the status of a service resource within a specified timeout period.
+
+    This function connects to a MySQL database and queries the status of a service resource
+    associated with a given hostname and service description. It repeatedly checks the status
+    until the specified timeout period is reached. The function can check for different state types
+    (SOFT, HARD, or ANY).
+
+    Args:
+        hostname (str): The name of the host.
+        service_desc (str): The description of the service.
+        status (int): The desired status to check for.
+        timeout (int): The timeout period in seconds.
+        state_type (str, optional): The type of state to check for. Defaults to "SOFT".
+                                    Can be "SOFT", "HARD", or "ANY".
+
+    Returns:
+        tuple: A tuple containing a boolean indicating if the desired status was found and the output message.
+               (True, output) if the desired status is found within the timeout period.
+               (False, "") if the desired status is not found within the timeout period.
+    """
+    limit = time.time() + timeout
+    while time.time() < limit:
+        connection = pymysql.connect(host=DB_HOST,
+                                     user=DB_USER,
+                                     password=DB_PASS,
+                                     autocommit=True,
+                                     database=DB_NAME_STORAGE,
+                                     charset='utf8mb4',
+                                     cursorclass=pymysql.cursors.DictCursor)
+
+        with connection:
+            with connection.cursor() as cursor:
+                cursor.execute(
+                    f"SELECT r.status,r.status_confirmed,r.output FROM resources r LEFT JOIN services s ON r.id=s.service_id AND r.parent_id=s.host_id LEFT JOIN hosts h ON s.host_id=h.host_id WHERE h.name='{hostname}' AND s.description='{service_desc}'")
+                result = cursor.fetchall()
+                if len(result) > 0:
+                    logger.console(f"result: {result}")
+                if len(result) > 0 and result[0]['status'] is not None and int(result[0]['status']) == int(status):
+                    logger.console(
+                        f"status={result[0]['status']} and status_confirmed={result[0]['status_confirmed']}")
+                    if state_type == 'ANY':
+                        return True, result[0]['output']
+                    elif state_type == 'HARD' and int(result[0]['status_confirmed']) == 1:
+                        return True, result[0]['output']
+                    elif state_type == 'SOFT' and int(result[0]['status_confirmed']) == 0:
+                        return True, result[0]['output']
+        time.sleep(1)
+    return False, ""
+
+
 def ctn_check_acknowledgement_with_timeout(hostname: str, service_desc: str, entry_time: int, status: int, timeout: int, state_type: str = "SOFT"):
     limit = time.time() + timeout
     while time.time() < limit:
@@ -711,12 +837,54 @@ def ctn_check_service_status_with_timeout(hostname: str, service_desc: str, stat
                         f"status={result[0]['state']} and state_type={result[0]['state_type']}")
                     if state_type == 'HARD' and int(result[0]['state_type']) == 1:
                         return True
-                    elif state_type != 'HARD':
+                    elif state_type != 'HARD' and int(result[0]['state_type']) == 0:
                         return True
         time.sleep(1)
     return False
 
 
+def ctn_check_service_status_with_timeout_rt(hostname: str, service_desc: str, status: int, timeout: int, state_type: str = "SOFT"):
+    """
+    ctn_check_service_status_with_timeout_rt
+
+    same as ctn_check_service_status_with_timeout but returns a pair boolean, output
+
+    Args:
+        host_name:
+        service_desc:
+        status: expected service state
+        state_type: HARD, SOFT or ANY
+        timeout: time to wait expected check in seconds
+    """
+
+    limit = time.time() + timeout
+    while time.time() < limit:
+        connection = pymysql.connect(host=DB_HOST,
+                                     user=DB_USER,
+                                     password=DB_PASS,
+                                     autocommit=True,
+                                     database=DB_NAME_STORAGE,
+                                     charset='utf8mb4',
+                                     cursorclass=pymysql.cursors.DictCursor)
+
+        with connection:
+            with connection.cursor() as cursor:
+                cursor.execute(
+                    f"SELECT s.state, s.state_type, s.output FROM services s LEFT JOIN hosts h ON s.host_id=h.host_id WHERE s.description=\"{service_desc}\" AND h.name=\"{hostname}\"")
+                result = cursor.fetchall()
+                if len(result) > 0 and result[0]['state'] is not None and int(result[0]['state']) == int(status):
+                    logger.console(
+                        f"status={result[0]['state']} and state_type={result[0]['state_type']} and output={result[0]['output']}")
+                    if state_type == 'HARD' and int(result[0]['state_type']) == 1:
+                        return True, result[0]['output']
+                    elif state_type != 'SOFT' and int(result[0]['state_type']) == 0:
+                        return True, result[0]['output']
+                    else:
+                        return True, result[0]['output']
+        time.sleep(1)
+    return False, ""
+
+
 def ctn_check_service_status_enabled(hostname: str, service_desc: str, timeout: int):
     limit = time.time() + timeout
     while time.time() < limit:
@@ -841,6 +1009,7 @@ def ctn_check_ba_status_with_timeout(ba_name: str, status: int, timeout: int):
                                      cursorclass=pymysql.cursors.DictCursor)
         with connection:
             with connection.cursor() as cursor:
+
                 logger.console(f"SELECT * from mod_bam WHERE name='{ba_name}'")
                 cursor.execute(
                     f"SELECT * FROM mod_bam WHERE name='{ba_name}'")
@@ -1044,7 +1213,7 @@ def ctn_check_service_check_status_with_timeout(hostname: str, service_desc: str
 
 def ctn_check_service_output_resource_status_with_timeout(hostname: str, service_desc: str, timeout: int, min_last_check: int, status: int, status_type: str,  output: str):
     """
-    ctn_check_host_output_resource_status_with_timeout
+    ctn_check_service_output_resource_status_with_timeout
 
     check if resource checks infos of an host have been updated
 
@@ -1077,7 +1246,7 @@ def ctn_check_service_output_resource_status_with_timeout(hostname: str, service
                     logger.console(f"result: {result}")
                 if len(result) > 0 and result[0]['status'] is not None and int(result[0]['status']) == int(status):
                     logger.console(
-                        f"status={result[0]['status']} and status_confirmed={result[0]['status_confirmed']}")
+                        f"status={result[0]['status']} and status_confirmed={result[0]['status_confirmed']} and output=\"{result[0]['output']}\"")
                     if status_type == 'HARD' and int(result[0]['status_confirmed']) == 1 and output in result[0]['output']:
                         return True
                     elif status_type == 'SOFT' and int(result[0]['status_confirmed']) == 0 and output in result[0]['output']:
@@ -1086,7 +1255,19 @@ def ctn_check_service_output_resource_status_with_timeout(hostname: str, service
     return False
 
 
-def ctn_check_host_check_with_timeout(hostname: str, timeout: int, command_line: str):
+def ctn_check_host_check_with_timeout(hostname: str, start: int, timeout: int):
+    """
+    ctl_check_host_check_with_timeout
+
+    Checks that the last_check is after the start timestamp.
+
+    Args:
+        hostname: the host concerned by the check
+        start: a timestamp that should be approximatively the date of the check.
+        timeout: A timeout.
+
+    Returns: True on success.
+    """
     limit = time.time() + timeout
     while time.time() < limit:
         connection = pymysql.connect(host=DB_HOST,
@@ -1100,12 +1281,13 @@ def ctn_check_host_check_with_timeout(hostname: str, timeout: int, command_line:
         with connection:
             with connection.cursor() as cursor:
                 cursor.execute(
-                    f"SELECT command_line FROM hosts WHERE name='{hostname}'")
+                    f"SELECT last_check FROM resources WHERE name='{hostname}'")
                 result = cursor.fetchall()
-                if len(result) > 0:
+                if len(result) > 0 and len(result[0]) > 0 and result[0]['last_check'] is not None:
                     logger.console(
-                        f"command_line={result[0]['command_line']} ")
-                    if result[0]['command_line'] is not None and command_line in result[0]['command_line']:
+                        f"last_check={result[0]['last_check']} ")
+                    last_check = int(result[0]['last_check'])
+                    if last_check > start:
                         return True
         time.sleep(1)
     return False
@@ -1144,6 +1326,9 @@ def ctn_check_host_check_status_with_timeout(hostname: str, timeout: int, min_la
                         f"last_check={result[0]['last_check']} state={result[0]['state']} output={result[0]['output']} ")
                     if result[0]['last_check'] is not None and result[0]['last_check'] >= min_last_check and output in result[0]['output'] and result[0]['state'] == state:
                         return True
+                    else:
+                        logger.console(
+                            f"last_check: {result[0]['last_check']} - min_last_check: {min_last_check} - expected output: {output} - output: {result[0]['output']} - expected state: {state} - state: {result[0]['state']}")
         time.sleep(1)
     return False
 
@@ -1348,7 +1533,7 @@ def ctn_check_resources_tags_with_timeout(parent_id: int, mid: int, typ: str, ta
         tag_ids: expected tags ids
         timeout: timeout in seconds
         enabled: if True, check if the tags are enabled, otherwise check if they are different
-        Returns: 
+        Returns:
            - enabled = True: True if the tags resource (parent_id, mid) is attached to all tags in tag_ids
            - enabled = False: True if resource (parent_id, mid) is attached to none tag of tag_ids
 
@@ -1502,6 +1687,8 @@ def ctn_check_number_of_relations_between_hostgroup_and_hosts(hostgroup: int, va
                     "SELECT count(*) FROM hosts_hostgroups WHERE hostgroup_id={}".format(hostgroup))
                 result = cursor.fetchall()
                 if len(result) > 0:
+                    logger.console(
+                        f"SELECT count(*) FROM hosts_hostgroups WHERE hostgroup_id={hostgroup} => {result[0]}")
                     if int(result[0]['count(*)']) == value:
                         return True
         time.sleep(1)
@@ -1680,56 +1867,6 @@ def ctn_check_types_in_resources(lst: list):
     return False
 
 
-def ctn_check_host_dependencies(dep_host_id, host_id, dep_period, inherits_parent, notif_fail_opts, exec_fail_opts, timeout=TIMEOUT):
-    limit = time.time() + timeout
-    logger.console(
-        f"SELECT count(*) FROM hosts_hosts_dependencies WHERE dependent_host_id={dep_host_id} AND host_id={host_id} AND dependency_period='{dep_period}' AND inherits_parent={inherits_parent} AND notification_failure_options='{notif_fail_opts}' AND execution_failure_options='{exec_fail_opts}'")
-    while time.time() < limit:
-        connection = pymysql.connect(host=DB_HOST,
-                                     user=DB_USER,
-                                     password=DB_PASS,
-                                     database=DB_NAME_STORAGE,
-                                     charset='utf8mb4',
-                                     autocommit=True,
-                                     cursorclass=pymysql.cursors.DictCursor)
-
-        with connection:
-            with connection.cursor() as cursor:
-                cursor.execute("SELECT * FROM hosts_hosts_dependencies")
-                result = cursor.fetchall()
-                logger.console(result)
-                cursor.execute(
-                    f"SELECT count(*) FROM hosts_hosts_dependencies WHERE dependent_host_id={dep_host_id} AND host_id={host_id} AND dependency_period='{dep_period}' AND inherits_parent={inherits_parent} AND notification_failure_options='{notif_fail_opts}' AND execution_failure_options='{exec_fail_opts}'")
-                result = cursor.fetchall()
-                logger.console(result)
-                if len(result) > 0 and int(result[0]['count(*)']) > 0:
-                    return True
-                time.sleep(2)
-    return False
-
-
-def ctn_check_no_host_dependencies(timeout=TIMEOUT):
-    limit = time.time() + timeout
-    logger.console("SELECT count(*) FROM hosts_hosts_dependencies")
-    while time.time() < limit:
-        connection = pymysql.connect(host=DB_HOST,
-                                     user=DB_USER,
-                                     password=DB_PASS,
-                                     database=DB_NAME_STORAGE,
-                                     charset='utf8mb4',
-                                     autocommit=True,
-                                     cursorclass=pymysql.cursors.DictCursor)
-
-        with connection:
-            with connection.cursor() as cursor:
-                cursor.execute(
-                    "SELECT count(*) FROM hosts_hosts_dependencies")
-                result = cursor.fetchall()
-                if len(result) > 0 and int(result[0]['count(*)']) == 0:
-                    return True
-    return False
-
-
 def ctn_get_collect_version():
     f = open("../CMakeLists.txt", "r")
     lines = f.readlines()
@@ -1752,6 +1889,29 @@ def ctn_get_collect_version():
     return f"{maj}.{mini}.{patch}"
 
 
+def ctn_get_cma_version():
+    f = open("../CMakeLists.txt", "r")
+    lines = f.readlines()
+    f.close()
+    filtered = filter(lambda line: line.startswith(
+        "set(COLLECT_") or line.startswith("set(AGENT_"), lines)
+
+    rmaj = re.compile(r"set\(COLLECT_MAJOR\s*([0-9]+)")
+    rmin = re.compile(r"set\(COLLECT_MINOR\s*([0-9]+)")
+    rpatch = re.compile(r"set\(AGENT_PATCH\s*([0-9]+)")
+    for line in filtered:
+        m1 = rmaj.match(line)
+        m2 = rmin.match(line)
+        m3 = rpatch.match(line)
+        if m1:
+            maj = m1.group(1)
+        if m2:
+            mini = m2.group(1)
+        if m3:
+            patch = m3.group(1)
+    return f"{maj}.{mini}.{patch}"
+
+
 def ctn_wait_until_file_modified(path: str, date: str, timeout: int = TIMEOUT):
     """! wait until file is modified
     @param path  path of the file
@@ -1915,7 +2075,7 @@ def ctn_extract_event_from_lua_log(file_path: str, field_name: str):
     """
     extract_event_from_lua_log
 
-    extract a json object from a lua log file 
+    extract a json object from a lua log file
     Example: Wed Feb  7 15:30:11 2024: INFO: {"_type":196621, "category":3, "element":13, "resource_metrics":{}
 
     Args:
@@ -1982,3 +2142,272 @@ def ctn_compare_string_with_file(string_to_compare: str, file_path: str):
         if str_line != file_line:
             return False
     return True
+
+
+def ctn_check_service_perfdata(host: str, serv: str, timeout: int, precision: float, expected: dict):
+    """
+    Check if performance data are near as expected.
+        host (str): The hostname of the service to check.
+        serv (str): The service name to check.
+        timeout (int): The timeout value for the check.
+        precision (float): The precision required for the performance data comparison.
+        expected (dict): A dictionary containing the expected performance data values.
+    """
+    limit = time.time() + timeout
+    query = f"""SELECT sub_query.metric_name, db.value FROM data_bin db JOIN
+            (SELECT m.metric_name, MAX(db.ctime) AS last_data, db.id_metric FROM data_bin db
+                JOIN metrics m ON db.id_metric = m.metric_id
+                JOIN index_data id ON id.id = m.index_id
+                WHERE id.host_name='{host}' AND id.service_description='{serv}'
+                GROUP BY m.metric_id) sub_query
+            ON db.ctime = sub_query.last_data AND db.id_metric = sub_query.id_metric"""
+    while time.time() < limit:
+        connection = pymysql.connect(host=DB_HOST,
+                                     user=DB_USER,
+                                     password=DB_PASS,
+                                     database=DB_NAME_STORAGE,
+                                     charset='utf8mb4',
+                                     cursorclass=pymysql.cursors.DictCursor)
+        with connection:
+            with connection.cursor() as cursor:
+                cursor.execute(query)
+                result = cursor.fetchall()
+                if len(result) >= len(expected):
+                    for res in result:
+                        logger.console(
+                            f"metric: {res['metric_name']}, value: {res['value']}")
+                        metric = res['metric_name']
+                        value = float(res['value'])
+                        # as windows agent is not restarted, he can send metrics from previous tests once engine is restarted, so we ignore them
+                        if metric not in expected:
+                            # as windows agent is not restarted, he can send metrics from previous tests once engine is restarted, so we ignore them
+                            continue
+                        if expected[metric] is not None and abs(value - expected[metric]) > precision:
+                            logger.console(
+                                f"ERROR unexpected value for {metric}, expected: {expected[metric]}, found: {value}")
+                            return False
+                    return True
+        time.sleep(1)
+    logger.console(f"unexpected result: {result}")
+    return False
+
+
+def ctn_check_service_check_interval(host: str, serv: str, timeout: int, expected_interval: int, precision: float):
+    """
+    Check if performance data of a metric are spaced of expected_interval.
+        host (str): The hostname of the service to check.
+        serv (str): The service name to check.
+        timeout (int): The timeout value for the check.
+        expected_interval (int): The expected interval between two performance data points.
+        precision (float): The precision required for the interval comparison.
+    """
+
+    # we work on last metric in order to not take into account metrics of previous tests
+    limit = time.time() + timeout
+    query = f"""SELECT  db.ctime, db.id_metric FROM data_bin db JOIN
+            (SELECT MAX(db.id_metric) AS id_metric FROM data_bin db
+                JOIN metrics m ON db.id_metric = m.metric_id
+                JOIN index_data id ON id.id = m.index_id
+                WHERE id.host_name='{host}' AND id.service_description='{serv}') sub_query
+            ON db.id_metric = sub_query.id_metric ORDER BY db.ctime"""
+    while time.time() < limit:
+        connection = pymysql.connect(host=DB_HOST,
+                                     user=DB_USER,
+                                     password=DB_PASS,
+                                     database=DB_NAME_STORAGE,
+                                     charset='utf8mb4',
+                                     cursorclass=pymysql.cursors.DictCursor)
+        with connection:
+            with connection.cursor() as cursor:
+                cursor.execute(query)
+                result = cursor.fetchall()
+                # we don't take first check into account as it may be generated by previous test
+                if (len(result) >= 3):
+                    for i in range(len(result) - 2):
+                        time_diff = result[i + 2]['ctime'] - \
+                            result[i + 1]['ctime']
+                        logger.console(
+                            f"serv:{serv}, metric: {result[i + 1]['id_metric']}, ctime:{result[i + 1]['ctime']}, time_diff: {time_diff}")
+                        if abs(time_diff - expected_interval) > precision:
+                            logger.console(
+                                f"ERROR unexpected interval, expected: {expected_interval}, found: {time_diff}")
+                            return False
+                    return True
+        time.sleep(1)
+    logger.console(f"unexpected result: {result}")
+    return False
+
+
+def ctn_check_agent_information(total_nb_agent: int, nb_poller: int, timeout: int):
+    """
+    Check if agent_information table is filled. Collect version is also checked
+        total_nb_agent (int): total number of agents
+        nb_poller (int): nb poller with at least one agent connected.
+        timeout (int): The timeout value for the check.
+    """
+    cma_version = ctn_get_cma_version()
+
+    cma_major = int(cma_version.split(".")[0])
+    cma_minor = int(cma_version.split(".")[1])
+    cma_patch = int(cma_version.split(".")[2])
+
+    limit = time.time() + timeout
+    query = "SELECT infos FROM agent_information WHERE enabled = 1"
+    while time.time() < limit:
+        connection = pymysql.connect(host=DB_HOST,
+                                     user=DB_USER,
+                                     password=DB_PASS,
+                                     database=DB_NAME_STORAGE,
+                                     charset='utf8mb4',
+                                     cursorclass=pymysql.cursors.DictCursor)
+        with connection:
+            with connection.cursor() as cursor:
+                cursor.execute(query)
+                result = cursor.fetchall()
+                if len(result) == nb_poller:
+                    nb_agent = 0
+                    for res in result:
+                        logger.console(f"infos: {res['infos']}")
+                        agent_infos = json.loads(res['infos'])
+                        for by_agent_info in agent_infos:
+                            if by_agent_info['agent_major'] != cma_major or by_agent_info['agent_minor'] != cma_minor or by_agent_info['agent_patch'] != cma_patch:
+                                logger.console(
+                                    f"unexpected version: {by_agent_info['agent_major']}.{by_agent_info['agent_minor']}.{by_agent_info['agent_patch']}")
+                                return False
+                            nb_agent += by_agent_info['nb_agent']
+                    if nb_agent == total_nb_agent:
+                        return True
+        time.sleep(1)
+    logger.console(f"unexpected result: {result}")
+    return False
+
+
+def ctn_get_nb_process(exe: str):
+    """
+    ctn_get_nb_process
+
+    get the number of process with a specific executable
+    Args:
+        exe: executable to search
+    Returns: number of process
+    """
+
+    counter = 0
+
+    for p in psutil.process_iter():
+        if exe in p.name() or exe in ' '.join(p.cmdline()):
+            counter += 1
+    return counter
+
+
+def ctn_check_service_flapping(host: str, serv: str, timeout: int, precision: float, expected: int):
+    """
+    Check if performance data are near as expected.
+        host (str): The hostname of the service to check.
+        serv (str): The service name to check.
+        timeout (int): The timeout value for the check.
+        precision (float): The precision required for the performance data comparison.
+        expected (int): expected flapping value.
+    """
+    limit = time.time() + timeout
+
+    s_query = f"""SELECT s.flapping, s.percent_state_change FROM services s JOIN hosts h on s.host_id = h.host_id  WHERE h.name='{host}' AND description='{serv}'"""
+    r_query = f"""SELECT flapping, percent_state_change FROM resources WHERE parent_name='{host}' AND name='{serv}'"""
+
+    while time.time() < limit:
+        connection = pymysql.connect(host=DB_HOST,
+                                     user=DB_USER,
+                                     password=DB_PASS,
+                                     database=DB_NAME_STORAGE,
+                                     charset='utf8mb4',
+                                     cursorclass=pymysql.cursors.DictCursor)
+        with connection:
+            with connection.cursor() as cursor:
+                cursor.execute(s_query)
+                result = cursor.fetchall()
+                if len(result) == 1 and result[0]['flapping'] == 1 and abs(result[0]['percent_state_change'] - expected) < precision:
+                    cursor.execute(r_query)
+                    result = cursor.fetchall()
+                    if len(result) == 1 and result[0]['flapping'] == 1 and abs(result[0]['percent_state_change'] - expected) < precision:
+                        return True
+        time.sleep(1)
+    logger.console(f"unexpected result: {result}")
+    return False
+
+
+def ctn_check_host_flapping(host: str, timeout: int, precision: float, expected: int):
+    """
+    Check if performance data are near as expected.
+        host (str): The hostname of the service to check.
+        timeout (int): The timeout value for the check.
+        precision (float): The precision required for the performance data comparison.
+        expected (int): expected flapping value.
+    """
+    limit = time.time() + timeout
+
+    s_query = f"""SELECT flapping, percent_state_change FROM hosts WHERE name='{host}'"""
+    r_query = f"""SELECT flapping, percent_state_change FROM resources WHERE name='{host}' AND parent_id=0"""
+
+    while time.time() < limit:
+        connection = pymysql.connect(host=DB_HOST,
+                                     user=DB_USER,
+                                     password=DB_PASS,
+                                     database=DB_NAME_STORAGE,
+                                     charset='utf8mb4',
+                                     cursorclass=pymysql.cursors.DictCursor)
+        with connection:
+            with connection.cursor() as cursor:
+                cursor.execute(s_query)
+                result = cursor.fetchall()
+                if len(result) == 1 and result[0]['flapping'] == 1 and abs(result[0]['percent_state_change'] - expected) < precision:
+                    cursor.execute(r_query)
+                    result = cursor.fetchall()
+                    if len(result) == 1 and result[0]['flapping'] == 1 and abs(result[0]['percent_state_change'] - expected) < precision:
+                        return True
+        time.sleep(1)
+    logger.console(f"unexpected result: {result}")
+    return False
+
+
+def ctn_get_process_limit(pid: int, limit: str):
+    """
+    ctn_get_process_limit
+
+    Get a limit of a process
+    Args:
+        pid: process id
+        limit: limit to get
+
+    Returns: limit value
+    """
+    try:
+        with open(f"/proc/{pid}/limits") as f:
+            for line in f:
+                if limit in line:
+                    fields = line.split()
+                    return int(fields[len(fields) - 3]), int(fields[len(fields) - 2])
+    except:
+        return -1, -1
+    return -1, -1
+
+
+def ctn_create_jwt_token(exp_s: int, secret: str = "centreon"):
+    """
+    ctn_create_jwt_token
+
+    create a jwt token
+    Returns: jwt token
+    """
+    value = random.randint(0, 100000)
+    now = datetime.now()
+    payload = {
+        "name": f"centreon{value}",
+        "iat": int(now.timestamp())
+    }
+    # if exp_s == -1, set exp to None (null in JWT)
+    if exp_s != -1:
+        payload["exp"] = int((now + timedelta(seconds=exp_s)).timestamp())
+    else:
+        payload["exp"] = None
+    logger.console(payload)
+    return jwt.encode(payload, secret, algorithm="HS256")
